"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.lab import get_con_lab


@pytest.mark.fast
def test_get_con_lab_data_one() -> None:
    label = get_con_lab(separator=" of ", country="11th government of turkey", start_get_country2=True)
    assert label != "حكومة تركيا"


data = [
    {"separator_stripped": "about", "country": "busan", "output": "بوسان"},
    {"separator_stripped": "about", "country": "chefs", "output": "طباخون"},
    {"separator_stripped": "about", "country": "slavery", "output": "العبودية"},
    {"separator_stripped": "about", "country": "south carolina", "output": "كارولاينا الجنوبية"},
    {"separator_stripped": "about", "country": "south dakota", "output": "داكوتا الجنوبية"},
    {"separator_stripped": "about", "country": "american civil war", "output": "الحرب الأهلية الأمريكية"},
    {"separator_stripped": "about", "country": "united states navy", "output": "البحرية الأمريكية"},
    {"separator_stripped": "about", "country": "vietnam war", "output": "حرب فيتنام"},
    {"separator_stripped": "about", "country": "weather", "output": "الطقس"},
    {"separator_stripped": "adapted for", "country": "other media", "output": "وسائط أخرى"},
    {"separator_stripped": "adapted into", "country": "films", "output": "أفلام"},
    {"separator_stripped": "against", "country": "united states", "output": "الولايات المتحدة"},
    {"separator_stripped": "at", "country": "yemen", "output": "اليمن"},
    {"separator_stripped": "based in", "country": "aomori prefecture", "output": "محافظة آوموري"},
    {"separator_stripped": "based in", "country": "belarus", "output": "روسيا البيضاء"},
    {"separator_stripped": "based in", "country": "illinois by populated place", "output": "إلينوي حسب المكان المأهول"},
    {"separator_stripped": "basedon", "country": "american comics", "output": "قصص مصورة أمريكية"},
    {"separator_stripped": "basedon", "country": "british television series", "output": "مسلسلات تلفزيونية بريطانية"},
    {"separator_stripped": "basedon", "country": "comics", "output": "قصص مصورة"},
    {"separator_stripped": "basedon", "country": "egyptian mythology", "output": "أساطير مصرية"},
    {"separator_stripped": "between", "country": "national teams", "output": "منتخبات وطنية"},
    {"separator_stripped": "built-in", "country": "montreal", "output": "مونتريال"},
    {"separator_stripped": "built-in", "country": "poland", "output": "بولندا"},
    {"separator_stripped": "by", "country": "by academic discipline", "output": "حسب التخصص الأكاديمي"},
    {"separator_stripped": "by", "country": "by american artists", "output": "بواسطة فنانون أمريكيون"},
    {"separator_stripped": "by", "country": "by andy warhol", "output": "بواسطة آندي وارهول"},
    {"separator_stripped": "by", "country": "by athletic event", "output": "حسب حدث ألعاب القوى"},
    {"separator_stripped": "by", "country": "by under-20 national team", "output": "حسب المنتخب الوطني تحت 20 سنة"},
    {"separator_stripped": "by", "country": "by year templates", "output": "قوالب حسب السنة"},
    {"separator_stripped": "by-car-bomb", "country": "in the united kingdom", "output": "في المملكة المتحدة"},
    {"separator_stripped": "closed in", "country": "1420", "output": "1420"},
    {"separator_stripped": "closed in", "country": "20th century", "output": "القرن 20"},
    {"separator_stripped": "completed in", "country": "1420s", "output": "عقد 1420"},
    {"separator_stripped": "completed in", "country": "2nd century", "output": "القرن 2"},
    {"separator_stripped": "concerning", "country": "eritrea", "output": "إرتريا"},
    {"separator_stripped": "created in", "country": "1420", "output": "1420"},
    {"separator_stripped": "demolished in", "country": "1420", "output": "1420"},
    {"separator_stripped": "described in", "country": "1420", "output": "1420"},
    {"separator_stripped": "described in", "country": "20th century", "output": "القرن 20"},
    {"separator_stripped": "discovered in", "country": "1420", "output": "1420"},
    {"separator_stripped": "disestablished in", "country": "1420 by country", "output": "1420 حسب البلد"},
    {"separator_stripped": "disestablished in", "country": "14th century bc", "output": "القرن 14 ق م"},
    {
        "separator_stripped": "during",
        "country": "world-war-ii by nationality",
        "output": "الحرب العالمية الثانية حسب الجنسية",
    },
    {"separator_stripped": "during", "country": "world-war-ii", "output": "الحرب العالمية الثانية"},
    {"separator_stripped": "established in", "country": "1420s", "output": "عقد 1420"},
    {"separator_stripped": "established in", "country": "14th century", "output": "القرن 14"},
    {"separator_stripped": "extended to", "country": "curaçao", "output": "كوراساو"},
    {"separator_stripped": "filmed in", "country": "algeria", "output": "الجزائر"},
    {"separator_stripped": "filmed in", "country": "jiangsu", "output": "جيانغسو"},
    {"separator_stripped": "for", "country": "for argentina", "output": "الأرجنتين"},
    {"separator_stripped": "for", "country": "for australia", "output": "أستراليا"},
    {"separator_stripped": "for", "country": "for german-language films", "output": "أفلام باللغة الألمانية"},
    {"separator_stripped": "for", "country": "for germany", "output": "ألمانيا"},
    {"separator_stripped": "for", "country": "for national teams", "output": "للمنتخبات الوطنية"},
    {"separator_stripped": "for", "country": "for women's football", "output": "كرة القدم للسيدات"},
    {"separator_stripped": "from", "country": "aden", "output": "عدن"},
    {"separator_stripped": "from", "country": "ahrweiler (district)", "output": "أرفيلر"},
    {"separator_stripped": "from", "country": "georgia (country)", "output": "جورجيا"},
    {"separator_stripped": "from", "country": "georgia (u.s. state)", "output": "ولاية جورجيا"},
    {
        "separator_stripped": "from",
        "country": "northern ireland of canadian descent",
        "output": "أيرلندا الشمالية من أصل كندي",
    },
    {"separator_stripped": "hosted by", "country": "argentina", "output": "الأرجنتين"},
    {"separator_stripped": "imprisoned-in", "country": "germany", "output": "ألمانيا"},
    {"separator_stripped": "in", "country": "1420 all-africa games", "output": "ألعاب عموم إفريقيا 1420"},
    {"separator_stripped": "in", "country": "1420 world games", "output": "دورة الألعاب العالمية 1420"},
    {"separator_stripped": "in", "country": "1420–51", "output": "1420–51"},
    {"separator_stripped": "in", "country": "abkhazia", "output": "أبخازيا"},
    {"separator_stripped": "in", "country": "afghanistan", "output": "أفغانستان"},
    {"separator_stripped": "in", "country": "german novels of 20th century", "output": "روايات ألمانية في القرن 20"},
    {"separator_stripped": "in", "country": "mandatory syria", "output": "الانتداب الفرنسي على سوريا ولبنان"},
    {"separator_stripped": "in", "country": "socialist republic-of macedonia", "output": "جمهورية مقدونيا الاشتراكية"},
    {"separator_stripped": "in", "country": "universiade navigational boxes", "output": "صناديق تصفح الألعاب الجامعية"},
    {"separator_stripped": "in-sports-in", "country": "california", "output": "كاليفورنيا"},
    {"separator_stripped": "in-sports-in", "country": "delaware", "output": "ديلاوير"},
    {"separator_stripped": "introduced in", "country": "21st century", "output": "القرن 21"},
    {"separator_stripped": "involving", "country": "north macedonia", "output": "مقدونيا الشمالية"},
    {"separator_stripped": "involving the", "country": "united states", "output": "الولايات المتحدة"},
    {"separator_stripped": "murdered in", "country": "1420", "output": "1420"},
    {
        "separator_stripped": "murdered in",
        "country": "india by state or union territory",
        "output": "الهند حسب الولاية أو الإقليم الاتحادي",
    },
    {"separator_stripped": "named after", "country": "american explorers", "output": "مستكشفون أمريكيون"},
    {"separator_stripped": "named after", "country": "american novelists", "output": "روائيون أمريكيون"},
    {"separator_stripped": "named after", "country": "canadian awards", "output": "جوائز كندية"},
    {"separator_stripped": "named after", "country": "indian politicians", "output": "سياسيون هنود"},
    {"separator_stripped": "named after", "country": "populated places in latvia", "output": "أماكن مأهولة في لاتفيا"},
    {
        "separator_stripped": "named after",
        "country": "populated places in portugal",
        "output": "أماكن مأهولة في البرتغال",
    },
    {"separator_stripped": "named after", "country": "religious organizations", "output": "منظمات دينية"},
    {"separator_stripped": "named after", "country": "slovak musicians", "output": "موسيقيون سلوفاكيون"},
    {
        "separator_stripped": "of",
        "country": "british television series characters",
        "output": "شخصيات مسلسلات تلفزيونية بريطانية",
    },
    {"separator_stripped": "of", "country": "ottoman–persian wars", "output": "الحروب العثمانية الفارسية"},
    {"separator_stripped": "of", "country": "prime ministers of malaysia", "output": "رؤساء وزراء ماليزيا"},
    {"separator_stripped": "of", "country": "westchester county, new york", "output": "مقاطعة ويستتشستر (نيويورك)"},
    {"separator_stripped": "on", "country": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator_stripped": "on", "country": "diplomatic missions", "output": "بعثات دبلوماسية"},
    {"separator_stripped": "on", "country": "moon", "output": "القمر"},
    {
        "separator_stripped": "on",
        "country": "the-national-register-of-historic-places",
        "output": "السجل الوطني للأماكن التاريخية",
    },
    {"separator_stripped": "opened in", "country": "19th century", "output": "القرن 19"},
    {"separator_stripped": "originating in", "country": "turkey", "output": "تركيا"},
    {"separator_stripped": "produced by", "country": "brian wilson", "output": "بريان ويلسون"},
    {"separator_stripped": "produced in", "country": "alberta", "output": "ألبرتا"},
    {"separator_stripped": "published in", "country": "finland", "output": "فنلندا"},
    {"separator_stripped": "published in", "country": "western australia", "output": "أستراليا الغربية"},
    {"separator_stripped": "related to", "country": "future", "output": "المستقبل"},
    {"separator_stripped": "remade-in", "country": "other languages", "output": "لغات أخرى"},
    {"separator_stripped": "scored by", "country": "spanish composers", "output": "ملحنون إسبان"},
    {"separator_stripped": "sentenced to", "country": "death", "output": "الموت"},
    {"separator_stripped": "set in", "country": "10th century", "output": "القرن 10"},
    {"separator_stripped": "set in", "country": "australia by city", "output": "أستراليا حسب المدينة"},
    {"separator_stripped": "shot in", "country": "china by city", "output": "الصين حسب المدينة"},
    {"separator_stripped": "to", "country": "american samoa", "output": "ساموا الأمريكية"},
    {"separator_stripped": "to", "country": "north korea", "output": "كوريا الشمالية"},
    {
        "separator_stripped": "to",
        "country": "united states house-of-representatives from missouri territory",
        "output": "مجلس النواب الأمريكي من إقليم ميزوري",
    },
    {"separator_stripped": "to", "country": "united states", "output": "الولايات المتحدة"},
    {"separator_stripped": "to", "country": "togo", "output": "توغو"},
    {"separator_stripped": "to", "country": "venezuela", "output": "فنزويلا"},
    {"separator_stripped": "to", "country": "zimbabwe", "output": "زيمبابوي"},
    {"separator_stripped": "who died in", "country": "prison custody", "output": "السجن"},
    {"separator_stripped": "with screenplays by", "country": "matt damon", "output": "مات ديمون"},
    {"separator_stripped": "written by", "country": "lady gaga", "output": "ليدي غاغا"},
]


@pytest.mark.parametrize("tab", data, ids=lambda x: f"{x['separator_stripped']} {x['country']}")
# @pytest.mark.fast
def test_get_con_lab_data(tab) -> None:
    label = get_con_lab(separator=f" {tab['separator_stripped']} ", country=tab["country"], start_get_country2=True)
    assert label == tab["output"]


data_test = [
    ("based in", "alaska by populated place", "ألاسكا حسب المكان المأهول"),
    ("based in", "ivory coast by subject", "ساحل العاج حسب الموضوع"),
    ("based in", "north america by country", "أمريكا الشمالية حسب البلد"),
    ("based in", "south america by country", "أمريكا الجنوبية حسب البلد"),
    ("by", "by century and occupation", "حسب القرن والمهنة"),
    ("by", "by century of closing", "حسب قرن الاغلاق"),
    ("by", "by city in colombia", "حسب المدينة في كولومبيا"),
    ("by", "by city in northern-ireland", "حسب المدينة في أيرلندا الشمالية"),
    ("by", "by club or team", "حسب النادي أو الفريق"),
    ("by", "by county in taiwan", "حسب المقاطعة في تايوان"),
    ("by", "by educational institution in derbyshire", "حسب الهيئة التعليمية في داربيشير"),
    ("by", "by hong kong producers", "بواسطة منتجون هونغ كونغيون"),
    ("by", "by league in the united states", "حسب الدوري في الولايات المتحدة"),
    ("by", "by location and occupation", "حسب الموقع والمهنة"),
    ("by", "by ludwig van beethoven", "بواسطة لودفيج فان بيتهوفن"),
    ("by", "by nation and year", "حسب الموطن والسنة"),
    ("by", "by occupation and region", "حسب المهنة والمنطقة"),
    ("by", "by period of introduction", "حسب حقبة الاستحداث"),
    ("by", "by populated place and decade", "حسب المكان المأهول والعقد"),
    ("by", "by populated place and occupation", "حسب المكان المأهول والمهنة"),
    ("by", "by province or territory", "حسب المقاطعة أو الإقليم"),
    ("by", "by robert louis stevenson", "بواسطة روبرت لويس ستيفنسون"),
    ("by", "by sport and year", "حسب الرياضة والسنة"),
    ("by", "by state or territory", "حسب الولاية أو الإقليم"),
    ("by", "by state or union territory", "حسب الولاية أو الإقليم الاتحادي"),
    ("by", "by team in the united states", "حسب الفريق في الولايات المتحدة"),
    ("by", "by university or college in beijing", "حسب الجامعة أو الكلية في بكين"),
    ("by", "by university or college in guatemala", "حسب الجامعة أو الكلية في غواتيمالا"),
    ("by", "by university or college in india", "حسب الجامعة أو الكلية في الهند"),
    ("by", "by university or college in mauritius", "حسب الجامعة أو الكلية في موريشيوس"),
    ("by", "by university or college in nebraska", "حسب الجامعة أو الكلية في نبراسكا"),
    ("by", "by university or college in north carolina", "حسب الجامعة أو الكلية في كارولاينا الشمالية"),
    ("by", "by university or college", "حسب الجامعة أو الكلية"),
    ("by", "by year and continent", "حسب السنة والقارة"),
    ("by", "by year of disestablishment", "حسب سنة الانحلال"),
    ("by", "by year of introduction", "حسب سنة الاستحداث"),
    ("for", "for malta ", "مالطا"),
    ("for", "for the british virgin islands", "جزر العذراء البريطانية"),
    ("for", "for the russian empire", "الإمبراطورية الروسية"),
    ("for", "for the soviet union", "الاتحاد السوفيتي"),
    ("for", "for the united states", "الولايات المتحدة"),
    ("from", " kingdom-of asturias", "مملكة أستورياس"),
    ("from", "alphen aan den rijn", "ألفن آن دن راين"),
    ("from", "city of westminster", "مدينة وستمنستر"),
    ("from", "london borough of lambeth", "لامبيث"),
    ("from", "province of valencia", "بلنسية (مقاطعة)"),
    ("from", "west midlands (county)", "مقاطعة ميدلاند الغربية"),
    ("from", "vila nova de gaia", "فيلا نوا دغايا"),
    ("in", " kingdom-of hanover", "مملكة هانوفر"),
    ("in", " kingdom-of sardinia", "مملكة سردينيا"),
    ("in", " kingdom-of sicily", "مملكة صقلية"),
    ("in", "1789 asian winter games", "الألعاب الآسيوية الشتوية 1789"),
    ("in", "1789 british empire games", "دورة ألعاب الإمبراطورية البريطانية 1789"),
    ("in", "1789 fifa women's world cup", "كأس العالم لكرة القدم للسيدات 1789"),
    ("in", "1789 fifa world cup", "كأس العالم لكرة القدم 1789"),
    ("in", "1789 pan american games", "دورة الألعاب الأمريكية 1789"),
    ("in", "buildings and structures in africa", "مبان ومنشآت في إفريقيا"),
    ("in", "gautam buddh nagar district", "مقاطعة جوتام بوذا نجر"),
    ("in", "insular areas of united states", "المناطق المعزولة في الولايات المتحدة"),
    ("in", "israeli reality television series", "مسلسلات تلفزيونية واقعية إسرائيلية"),
    ("in", "saint vincent and grenadines", "سانت فنسنت وجزر غرينادين"),
    ("in", "santa maria da feira", "سانتا ماريا دا فييرا"),
    ("in", "south korean women's sport", "رياضة كورية جنوبية نسائية"),
    ("in", "special region of yogyakarta", "يوجياكرتا"),
    ("in", "american civil war", "الحرب الأهلية الأمريكية"),
    ("in", "asian para games", "الألعاب البارالمبية الآسيوية"),
    ("in", "australian capital territory", "إقليم العاصمة الأسترالية"),
    ("in", "basque country (autonomous community)", "منطقة الباسك ذاتية الحكم"),
    ("in", "bay of plenty region", "إقليم خليج بانتي"),
    ("in", "british virgin islands", "جزر العذراء البريطانية"),
    ("in", "capital region of denmark", "إقليم هوفدستادن"),
    ("in", "central african republic", "جمهورية إفريقيا الوسطى"),
    ("in", "city of westminster", "مدينة وستمنستر"),
    ("in", "cocos (keeling) islands", "جزر كوكوس"),
    ("in", "collectivity of saint martin", "تجمع سان مارتين"),
    ("in", "croatian war of independence", "الحرب الكرواتية في استقلال"),
    ("in", "federated states-of micronesia", "ولايات ميكرونيسيا المتحدة"),
    ("in", "french colonial empire", "الإمبراطورية الاستعمارية الفرنسية"),
    ("in", "holy roman empire", "الإمبراطورية الرومانية المقدسة"),
    ("in", "irish free state", "الدولة الأيرلندية الحرة"),
    ("in", "northern mariana islands", "جزر ماريانا الشمالية"),
    ("in", "peerage of ireland", "نبلاء إيرلندا"),
    ("in", "real estate industry", "صناعة عقارية"),
    ("in", "region of southern denmark", "إقليم سيد دنمارك"),
    ("in", "socialist republic-of macedonia", "جمهورية مقدونيا الاشتراكية"),
    ("in", "spanish east indies", "جزر الهند الشرقية الإسبانية"),
    ("in", "summer olympics ", "الألعاب الأولمبية الصيفية"),
    ("in", "summer olympics navigational boxes", "صناديق تصفح الألعاب الأولمبية الصيفية"),
    ("in", "summer world university games", "ألعاب الجامعات العالمية الصيفية"),
    ("in", "turks and caicos islands", "جزر توركس وكايكوس"),
    ("in", "united arab emirates", "الإمارات العربية المتحدة"),
    ("in", "united states virgin islands", "جزر العذراء الأمريكية"),
    ("in", "university of galway", "جامعة جلوي"),
    ("in", "world aquatics championships", "بطولة العالم للرياضات المائية"),
    ("in", "world athletics championships", "بطولة العالم لألعاب القوى"),
    ("in", "udham singh nagar district", "مقاطعة اودهام سينغ نجر"),
    ("in", "ústí nad labem region", "إقليم أوستي ناد لابم"),
    # ("involving the", "islamic state of iraq and the levant", "تنظيم داعش"),
    ("named after", "organizations based in gabon", "منظمات مقرها في الغابون"),
    ("named after", "populated places in uruguay", "أماكن مأهولة في أوروغواي"),
    ("named after", "universities and colleges in ghana", "جامعات وكليات في غانا"),
    ("named after", "universities and colleges in uruguay", "جامعات وكليات في أوروغواي"),
    ("of", " kingdom-of italy (1789–1789)", "مملكة إيطاليا (1789–1789)"),
    ("of", " kingdom-of montenegro", "مملكة الجبل الأسود"),
    ("of", "aviation accidents or incidents", "حوادث طيران"),
    ("of", "azerbaijan soviet socialist republic", "الجمهورية الأذرية السوفيتية الاشتراكية"),
    ("of", "bosnia and herzegovina politicians", "سياسيون بوسنيون"),
    ("of", "companies of georgia (country)", "شركات في جورجيا"),
    ("of", "companies of southeast asia", "شركات في جنوب شرق آسيا"),
    ("of", "eighteenth dynasty of egypt", "الأسرة المصرية الثامنة عشر"),
    ("of", "federal subjects of russia", "كيانات روسيا الاتحادية"),
    ("of", "government of burkina faso", "حكومة بوركينا فاسو"),
    ("of", "indian schools and colleges", "مدارس وكليات هندية"),
    ("of", "indigenous peoples of americas", "شعوب أصلية في الأمريكتين"),
    ("of", "london borough of ealing", "إيلنغ"),
    ("of", "mexican drama television series episodes", "حلقات مسلسلات تلفزيونية درامية مكسيكية"),
    ("of", "mexican drama television series", "مسلسلات تلفزيونية درامية مكسيكية"),
    ("of", "order of british empire", "وسام الإمبراطورية البريطانية"),
    ("of", "parliament of england 1789", "برلمان إنجلترا 1789"),
    ("of", "parliament of great britain", "برلمان بريطانيا العظمى"),
    ("of", "parliament of northern ireland 1789–1789", "برلمان أيرلندا الشمالية 1789–1789"),
    ("of", "pays de la loire", "وادي اللوار"),
    ("of", "royal navy of oman", "البحرية السلطانية العمانية"),
    ("of", "são tomé and príncipe", "ساو تومي وبرينسيب"),
    ("of", "ukrainian soviet socialist republic", "جمهورية أوكرانيا السوفيتية الاشتراكية"),
    ("of", "united states air force", "القوات الجوية الأمريكية"),
    ("of", "united states gubernatorial elections", "انتخابات حكام الولايات المتحدة"),
    ("of", "united states virgin islands", "جزر العذراء الأمريكية"),
    (
        "of",
        "verkhovna rada of ukrainian soviet socialist republic",
        "المجلس الأعلى الأوكراني في جمهورية أوكرانيا السوفيتية الاشتراكية",
    ),
    ("of", "water of coquimbo region", "مياه في إقليم كوكيمبو"),
    ("of", "water of hambantota district", "مياه في مديرية هامبانتوتا"),
    ("of", "water of matale district", "مياه في مديرية ماتال"),
    ("of", "water of wilkes land", "مياه في ويلكس لاند"),
    ("set in", "north america by country", "أمريكا الشمالية حسب البلد"),
    ("to", "insular areas of united states", "المناطق المعزولة في الولايات المتحدة"),
    ("to", "saint kitts and nevis", "سانت كيتس ونيفيس"),
    ("to", "parliament of united kingdom", "برلمان المملكة المتحدة"),
    ("to", "united arab emirates", "الإمارات العربية المتحدة"),
    ("to", "united nations in geneva", "الأمم المتحدة في جنيف"),
    ("transferred-from", "united states navy to the royal navy", "البحرية الأمريكية إلى البحرية الملكية"),
]


@pytest.mark.parametrize("separator, country, output", data_test, ids=[x[1] for x in data_test])
@pytest.mark.fast
def test_get_con_lab_data2(separator: str, country: str, output: str) -> None:
    label = get_con_lab(separator=separator, country=country, start_get_country2=True)
    assert label == output



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

data6 = {
    "georgia (country) freestyle wrestling federation": "الاتحاد الجورجي للمصارعة الحرة",
    "philippine sailing (sport) federation": "الاتحاد الفلبيني لرياضة الإبحار",
}

ar_sport_team_data = {
    # "Yemeni football championships clubs": "أندية بطولة اليمن لكرة القدم",
    "british softball championshipszz": "بطولة المملكة المتحدة للكرة اللينة",
    "ladies british softball tour": "بطولة المملكة المتحدة للكرة اللينة للسيدات",
    "british football tour": "بطولة المملكة المتحدة لكرة القدم",
    "Yemeni football championships": "بطولة اليمن لكرة القدم",
    "german figure skating championships": "بطولة ألمانيا للتزلج الفني",
    "british figure skating championships": "بطولة المملكة المتحدة للتزلج الفني",
}


sport_jobs_female_data = {
    "dominican republic national football teams": "منتخبات كرة قدم وطنية دومينيكانية",
    "yemeni national softball teams": "منتخبات كرة لينة وطنية يمنية",
    "Women's National Basketball League": "الدوري الوطني لكرة السلة للسيدات",
    "northern ireland": "",
}


@pytest.mark.parametrize("category, expected_key", ar_sport_team_data.items(), ids=ar_sport_team_data.keys())
@pytest.mark.fast
def test_ar_sport_team_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", sport_jobs_female_data.items(), ids=sport_jobs_female_data.keys())
@pytest.mark.fast
def test_sport_jobs_female_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


TEMPORAL_CASES = [
    ("test_resolve_nats_sport_multi_v2", data6, resolve_nats_sport_multi_v2),
    ("test_ar_sport_team_data", ar_sport_team_data, resolve_nats_sport_multi_v2),
    ("test_sport_jobs_female_data", sport_jobs_female_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=True)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Helpers for resolving sports teams and language categories.

TODO: compare this file with ArWikiCats/new/handle_suffixes.py
"""

from __future__ import annotations

import functools

from ..helps import dump_data, logger
from ..new_resolvers.sports_resolvers import resolve_sports_main
from ..new_resolvers.sports_resolvers.raw_sports import wrap_team_xo_normal_2025_with_ends
from ..translations import SPORTS_KEYS_FOR_JOBS
from . import team_work
from .o_bots.utils import resolve_suffix_template


# @dump_data(1)
def resolve_team_suffix(normalized_team) -> str:
    return resolve_suffix_template(
        normalized_team,
        team_work.Teams_new_end_keys,
        lambda prefix: SPORTS_KEYS_FOR_JOBS.get(prefix, ""),
    )


@functools.lru_cache(maxsize=10000)
def get_teams_new(team_name: str) -> str:
    """Return the label for ``team_name`` using multiple heuristics.

    Args:
        team_name: The English club or team name to translate.

    Returns:
        The resolved Arabic label or an empty string when no mapping exists.
    """

    # إيجاد لاحقات التسميات الرياضية

    # قبل تطبيق الوظيفة
    # sports.py: len:"Teams new":  685955
    # بعد تطبيق الوظيفة
    # sports.py: len:"Teams new":  114691

    normalized_team = team_name.strip()

    logger.info(f'start get_teams_new team:"{normalized_team}"')

    # _ = resolve_team_suffix(normalized_team)  # TODO: remove after tests

    team_label = (
        resolve_sports_main(normalized_team)
        or wrap_team_xo_normal_2025_with_ends(normalized_team)
        or resolve_team_suffix(normalized_team)
        or ""
    )

    logger.info(f"get_teams_new: {team_label=} for normalized_team: ({normalized_team})")

    return team_label


__all__ = [
    "get_teams_new",
]



"""

TODO: merge with countries_names_sport_multi_v2.py

"""
import functools

from ...helps import dump_data, logger
from ...legacy_bots.make_bots.teams_mappings_ends import teams_label_mappings_ends
from ...new.handle_suffixes import resolve_sport_category_suffix_with_mapping
from ...translations import (
    SPORTS_KEYS_FOR_TEAM,
    countries_from_nat,
)
from ...translations_formats import MultiDataFormatterBaseV2, format_multi_data_v2

SPORT_FORMATS_ENAR_P17_TEAM = {
    "{en} national men's under-13 {en_sport} team": "منتخب {ar} {sport_team} تحت 13 سنة للرجال",
    "{en} national men's under-14 {en_sport} team": "منتخب {ar} {sport_team} تحت 14 سنة للرجال",
    "{en} national men's under-15 {en_sport} team": "منتخب {ar} {sport_team} تحت 15 سنة للرجال",
    "{en} national men's under-16 {en_sport} team": "منتخب {ar} {sport_team} تحت 16 سنة للرجال",
    "{en} national men's under-17 {en_sport} team": "منتخب {ar} {sport_team} تحت 17 سنة للرجال",
    "{en} national men's under-18 {en_sport} team": "منتخب {ar} {sport_team} تحت 18 سنة للرجال",
    "{en} national men's under-19 {en_sport} team": "منتخب {ar} {sport_team} تحت 19 سنة للرجال",
    "{en} national men's under-20 {en_sport} team": "منتخب {ar} {sport_team} تحت 20 سنة للرجال",
    "{en} national men's under-21 {en_sport} team": "منتخب {ar} {sport_team} تحت 21 سنة للرجال",
    "{en} national men's under-23 {en_sport} team": "منتخب {ar} {sport_team} تحت 23 سنة للرجال",
    "{en} national men's under-24 {en_sport} team": "منتخب {ar} {sport_team} تحت 24 سنة للرجال",
    "{en} national under-13 {en_sport} team": "منتخب {ar} {sport_team} تحت 13 سنة",
    "{en} national under-14 {en_sport} team": "منتخب {ar} {sport_team} تحت 14 سنة",
    "{en} national under-15 {en_sport} team": "منتخب {ar} {sport_team} تحت 15 سنة",
    "{en} national under-16 {en_sport} team": "منتخب {ar} {sport_team} تحت 16 سنة",
    "{en} national under-17 {en_sport} team": "منتخب {ar} {sport_team} تحت 17 سنة",
    "{en} national under-18 {en_sport} team": "منتخب {ar} {sport_team} تحت 18 سنة",
    "{en} national under-19 {en_sport} team": "منتخب {ar} {sport_team} تحت 19 سنة",
    "{en} national under-20 {en_sport} team": "منتخب {ar} {sport_team} تحت 20 سنة",
    "{en} national under-21 {en_sport} team": "منتخب {ar} {sport_team} تحت 21 سنة",
    "{en} national under-23 {en_sport} team": "منتخب {ar} {sport_team} تحت 23 سنة",
    "{en} national under-24 {en_sport} team": "منتخب {ar} {sport_team} تحت 24 سنة",
    "{en} national women's under-13 {en_sport} team": "منتخب {ar} {sport_team} تحت 13 سنة للسيدات",
    "{en} national women's under-14 {en_sport} team": "منتخب {ar} {sport_team} تحت 14 سنة للسيدات",
    "{en} national women's under-15 {en_sport} team": "منتخب {ar} {sport_team} تحت 15 سنة للسيدات",
    "{en} national women's under-16 {en_sport} team": "منتخب {ar} {sport_team} تحت 16 سنة للسيدات",
    "{en} national women's under-17 {en_sport} team": "منتخب {ar} {sport_team} تحت 17 سنة للسيدات",
    "{en} national women's under-18 {en_sport} team": "منتخب {ar} {sport_team} تحت 18 سنة للسيدات",
    "{en} national women's under-19 {en_sport} team": "منتخب {ar} {sport_team} تحت 19 سنة للسيدات",
    "{en} national women's under-20 {en_sport} team": "منتخب {ar} {sport_team} تحت 20 سنة للسيدات",
    "{en} national women's under-21 {en_sport} team": "منتخب {ar} {sport_team} تحت 21 سنة للسيدات",
    "{en} national women's under-23 {en_sport} team": "منتخب {ar} {sport_team} تحت 23 سنة للسيدات",
    "{en} national women's under-24 {en_sport} team": "منتخب {ar} {sport_team} تحت 24 سنة للسيدات",
    "{en} national youth under-13 {en_sport} team": "منتخب {ar} {sport_team} تحت 13 سنة للشباب",
    "{en} national youth under-14 {en_sport} team": "منتخب {ar} {sport_team} تحت 14 سنة للشباب",
    "{en} national youth under-15 {en_sport} team": "منتخب {ar} {sport_team} تحت 15 سنة للشباب",
    "{en} national youth under-16 {en_sport} team": "منتخب {ar} {sport_team} تحت 16 سنة للشباب",
    "{en} national youth under-17 {en_sport} team": "منتخب {ar} {sport_team} تحت 17 سنة للشباب",
    "{en} national youth under-18 {en_sport} team": "منتخب {ar} {sport_team} تحت 18 سنة للشباب",
    "{en} national youth under-19 {en_sport} team": "منتخب {ar} {sport_team} تحت 19 سنة للشباب",
    "{en} national youth under-20 {en_sport} team": "منتخب {ar} {sport_team} تحت 20 سنة للشباب",
    "{en} national youth under-21 {en_sport} team": "منتخب {ar} {sport_team} تحت 21 سنة للشباب",
    "{en} national youth under-23 {en_sport} team": "منتخب {ar} {sport_team} تحت 23 سنة للشباب",
    "{en} national youth under-24 {en_sport} team": "منتخب {ar} {sport_team} تحت 24 سنة للشباب",
    "{en} national youth women's under-13 {en_sport} team": "منتخب {ar} {sport_team} تحت 13 سنة للشابات",
    "{en} national youth women's under-14 {en_sport} team": "منتخب {ar} {sport_team} تحت 14 سنة للشابات",
    "{en} national youth women's under-15 {en_sport} team": "منتخب {ar} {sport_team} تحت 15 سنة للشابات",
    "{en} national youth women's under-16 {en_sport} team": "منتخب {ar} {sport_team} تحت 16 سنة للشابات",
    "{en} national youth women's under-17 {en_sport} team": "منتخب {ar} {sport_team} تحت 17 سنة للشابات",
    "{en} national youth women's under-18 {en_sport} team": "منتخب {ar} {sport_team} تحت 18 سنة للشابات",
    "{en} national youth women's under-19 {en_sport} team": "منتخب {ar} {sport_team} تحت 19 سنة للشابات",
    "{en} national youth women's under-20 {en_sport} team": "منتخب {ar} {sport_team} تحت 20 سنة للشابات",
    "{en} national youth women's under-21 {en_sport} team": "منتخب {ar} {sport_team} تحت 21 سنة للشابات",
    "{en} national youth women's under-23 {en_sport} team": "منتخب {ar} {sport_team} تحت 23 سنة للشابات",
    "{en} national youth women's under-24 {en_sport} team": "منتخب {ar} {sport_team} تحت 24 سنة للشابات",
}


@functools.lru_cache(maxsize=1)
def _load_bot() -> MultiDataFormatterBaseV2:
    nats_data = {x: {"ar": v} for x, v in countries_from_nat.items()}

    sports_data = {
        x: {
            "sport_team": v,
        }
        for x, v in SPORTS_KEYS_FOR_TEAM.items()
    }

    both_bot = format_multi_data_v2(
        formatted_data=SPORT_FORMATS_ENAR_P17_TEAM,
        data_list=nats_data,
        key_placeholder="{en}",
        data_list2=sports_data,
        key2_placeholder="{en_sport}",
        text_after="",
        text_before="the ",
        search_first_part=True,
        use_other_formatted_data=True,
    )
    return both_bot


@functools.lru_cache(maxsize=10000)
def _get_p17_with_sport(category: str) -> str:
    if countries_from_nat.get(category):
        return ""

    logger.debug(f"<<yellow>> start _get_p17_with_sport: {category=}")

    both_bot = _load_bot()
    result = both_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end _get_p17_with_sport: {category=}, {result=}", result)
    return result


@functools.lru_cache(maxsize=10000)
def fix_keys(category: str) -> str:
    category = category.lower().replace("category:", "")
    # category = category.replace("'", "")

    replacements = {}

    for old, new in replacements.items():
        category = category.replace(old, new)

    return category.strip()


def fix_result_callable(result: str, category: str, key: str, value: str) -> str:
    if result.startswith("لاعبو ") and "للسيدات" in result:
        result = result.replace("لاعبو ", "لاعبات ")

    if key == "teams" and "national" in category:
        result = result.replace("فرق ", "منتخبات ")

    return result


@functools.lru_cache(maxsize=10000)
# @dump_data()
def get_p17_with_sport_new(category: str) -> str:
    category = fix_keys(category)

    logger.debug(f"<<yellow>> start get_p17_with_sport_new: {category=}")

    result = resolve_sport_category_suffix_with_mapping(
        category=category,
        data=teams_label_mappings_ends,
        callback=_get_p17_with_sport,
        fix_result_callable=fix_result_callable,
    )

    logger.info_if_or_debug(f"<<yellow>> end get_p17_with_sport_new: {category=}, {result=}", result)
    return result


__all__ = [
    "get_p17_with_sport_new",
]



#!/usr/bin/python3
"""Integration tests """

import re

import pytest

from ArWikiCats.translations_formats import FormatData


@pytest.fixture
def yc_bot() -> FormatData:
    formatted_data = {
        "{nat_en} actors": "ممثلون {nat_ar}",
        "{nat_en} people actors": "أعلام ممثلون {nat_ar}",
    }
    return FormatData(
        formatted_data=formatted_data,
        data_list={"yemeni": "يمنيون"},
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        text_before="the ",
        text_after=" people",
    )


def test_with_text_after(yc_bot: FormatData) -> None:
    """Test FormatData with text_after parameter."""
    category = "yemeni people actors"
    result = yc_bot.create_label(category)

    assert result == "أعلام ممثلون يمنيون"


def test_with_text_before(yc_bot: FormatData) -> None:
    """Test FormatData with text_before parameter."""
    category = "the yemeni actors"
    result = yc_bot.create_label(category)

    assert result == "ممثلون يمنيون"


def test_new_after_key() -> None:
    """Test FormatData with text_after parameter."""
    formatted_data = {
        "{nat_en} actors": "ممثلون {nat_ar}",
    }

    bot = FormatData(
        formatted_data=formatted_data,
        data_list={"yemeni": "يمنيون"},
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        text_before="the ",
        text_after=" people",
    )

    category = "yemeni people actors"
    result = bot.create_label(category)

    assert result == "ممثلون يمنيون"


def test_new_before_key() -> None:
    """Test FormatData with text_after parameter."""
    formatted_data = {
        "the {nat_en} actors": "ممثلون {nat_ar}",
    }

    bot = FormatData(
        formatted_data=formatted_data,
        data_list={"yemeni": "يمنيون"},
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        text_before="the ",  # dosn't matter here because "the {nat_en} actors" is in formatted_data
        text_after=" people",
    )

    category = "the yemeni actors"
    result = bot.create_label(category)

    assert result == "ممثلون يمنيون"



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import c_1_1_lab

test_data = {
    "american football teams": "فرق كرة قدم أمريكية",
    "art museums and galleries": "متاحف فنية ومعارض",
    "asian games medalists": "فائزون بميداليات الألعاب الآسيوية",
    "bosnia and herzegovina": "البوسنة والهرسك",
    "buildings and structures": "مبان ومنشآت",
    "by high school": "حسب المدرسة الثانوية",
    "by populated place and occupation": "حسب المكان المأهول والمهنة",
    "canadian chief executives": "رؤساء تنفيذيون كنديون",
    "cities and towns": "مدن وبلدات",
    "clubs and societies": "أندية وجمعيات",
    "covid-19 pandemic": "جائحة فيروس كورونا",
    "deaths due to animal attacks": "وفيات ناجمة عن هجمات الحيوانات",
    "deaths from cancer": "وفيات السرطان",
    "disused railway stations": "محطات سكك حديدية مهجورة",
    "dutch chief executives": "رؤساء تنفيذيون هولنديون",
    "electric power infrastructure": "بنية تحتية للقدرة الكهربائية",
    "field hockey clubs": "أندية هوكي ميدان",
    "field hockey playerss": "لاعبو هوكي ميدان",
    "finnish military personnel": "أفراد عسكريون فنلنديون",
    "food and drink": "أطعمة ومشروبات",
    "former buildings and structures": "مبان ومنشآت سابقة",
    "former populated places": "أماكن كانت مأهولة",
    "french-language radio stations": "محطات إذاعية باللغة الفرنسية",
    "gaelic football clubs": "أندية كرة قدم غالية",
    "german prisoners of war": "أسرى ألمان",
    "historic american buildings survey": "مسح المبان التاريخية الأمريكية",
    "hong kong businesspeople": "شخصيات أعمال هونغ كونغية",
    "ice hockey playerss": "لاعبو هوكي جليد",
    "indonesian expatriate sports-people": "رياضيون إندونيسيون مغتربون",
    "jews and judaism": "اليهود واليهودية",
    "libertarian party-of-canada candidates": "مرشحو الحزب التحرري الكندي",
    "mayors of places": "رؤساء بلديات",
    "media and communications": "الإعلام والاتصالات",
    "medical research institutes": "معاهد أبحاث طبية",
    "military units and formations": "وحدات وتشكيلات عسكرية",
    "monuments and memorials": "معالم أثرية ونصب تذكارية",
    "new democratic party candidates": "مرشحو الحزب الديمقراطي الجديد",
    "north american competitors": "منافسون أمريكيون شماليون",
    "pan american games silver medalists": "فائزون بميداليات فضية في دورة الألعاب الأمريكية",
    "papua new guinea": "بابوا غينيا الجديدة",
    "parks and open spaces": "متنزهات ومساحات مفتوحة",
    "places of worship": "أماكن عبادة",
    "polish air force": "القوات الجوية البولندية",
    "populated coastal places": "أماكن ساحلية مأهولة",
    "road incident deaths": "وفيات حوادث الطرق",
    "roman catholic archbishops": "رؤساء أساقفة رومان كاثوليك",
    "roman catholic bishops": "أساقفة كاثوليك رومان",
    "roman catholic churches": "كنائس رومانية كاثوليكية",
    "rugby league playerss": "لاعبو دوري رجبي",
    "rugby union leagues": "اتحاد دوري الرجبي",
    "rugby union teams": "فرق اتحاد رجبي",
    "science and technology": "العلوم والتقانة",
    "sierra leonean expatriates": "سيراليونيون مغتربون",
    "south african businesspeople": "شخصيات أعمال جنوب إفريقية",
    "south american competitors": "منافسون أمريكيون جنوبيون",
    "television series produced": "مسلسلات تلفزيونية أنتجت",
    "television series set": "مسلسلات تلفزيونية تقع أحداثها",
    "television shows filmed": "عروض تلفزيونية صورت",
    "television shows set": "عروض تلفزيونية تقع أحداثها",
    "television shows shot": "عروض تلفزيونية مصورة",
    "towns and villages": "بلدات وقرى",
    "track and field athletes": "رياضيو المسار والميدان",
    "transport buildings and structures": "مبان ومنشآت نقل",
    "united states house-of-representatives elections": "انتخابات مجلس النواب الأمريكي",
}


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_c_1_1_lab_3(category: str, expected: str) -> None:
    label = c_1_1_lab(" in ", category, with_years=False)
    assert label == expected



"""
Labs Years processing module.
"""

import functools
import re

from ..helps import logger
from ..patterns_resolvers.categories_patterns.YEAR_PATTERNS import YEAR_DATA, YEAR_PARAM_NAME
from .time_to_arabic import (
    convert_time_to_arabic,
    match_time_ar_first,
    match_time_en_first,
)
from .utils_time import fixing

YEAR_PARAM = "{year1}"


class MatchTimes:
    def __init__(self) -> None:
        pass

    def match_en_time(self, text: str) -> str:
        """Match English time in text."""
        # year_match = re.search(r"\d{4}", text)
        # if year_match: return year_match.group()
        result = match_time_en_first(text)
        logger.debug(f"match_en_time: {result=}")
        return result

    def match_ar_time(self, text: str) -> str:
        """Match Arabic time in text."""
        result = match_time_ar_first(text)
        logger.debug(f"match_ar_time: {result=}")
        return result


class LabsYears(MatchTimes):
    def __init__(self) -> None:
        """Prepare reusable lookup tables for year-based category labels."""
        self.lookup_count = 0
        self.category_templates = dict(YEAR_DATA)
        self.category_templates.update(
            {
                f"{YEAR_PARAM}": f"{YEAR_PARAM}",
                f"films in {YEAR_PARAM}": f"أفلام في {YEAR_PARAM}",
                f"{YEAR_PARAM} films": f"أفلام إنتاج {YEAR_PARAM}",
            }
        )

    def lab_from_year(self, category_r: str) -> tuple:
        """
        Given a string `category_r` representing a category, this function extracts the year from the category and returns a tuple containing the extracted year and the corresponding category key. If no year is found in the category, an empty string and an empty string are returned.

        Parameters:
        - `category_r` (str): The category from which to extract the year.

        Returns:
        - `tuple`: A tuple containing the extracted year and the corresponding category key. If no year is found, an empty string and an empty string are returned.
        """
        logger.debug(f"start lab_from_year: {category_r=}")
        from_year = ""
        cat_year = ""
        category_r = category_r.lower()
        year_match = self.match_en_time(category_r)

        if not year_match:
            logger.debug(f" end lab_from_year: {category_r=}, {cat_year=}")
            return cat_year, from_year

        cat_year = year_match
        cat_key = category_r.replace(cat_year, YEAR_PARAM).lower().replace("category:", "").strip()

        cat_year_ar = ""
        if cat_year.isdigit():
            cat_year_ar = cat_year
        else:
            cat_year_ar = convert_time_to_arabic(cat_year)

        canonical_label = self.category_templates.get(cat_key)

        if canonical_label and YEAR_PARAM in canonical_label and cat_year_ar:
            from_year = canonical_label.format_map({YEAR_PARAM_NAME: cat_year_ar})
            from_year = fixing(from_year)
            self.lookup_count += 1
            logger.info(f"<<green>> lab_from_year: {self.lookup_count}, {canonical_label=}")
            logger.info(f"\t<<green>> {category_r=} , {from_year=}")

        logger.debug(f"end lab_from_year: {category_r=}, {cat_year=}")
        return cat_year, from_year

    def lab_from_year_add(self, category_r: str, category_lab: str, en_year: str, ar_year: str = "") -> bool:
        """
        A function that converts the year in category_r and category_lab to YEAR_PARAM and updates the category_templates dictionary accordingly.
        Parameters:
            category_r (str): The category from which to update the year.
            category_lab (str): The category from which to update the year.
            cat_year (str): The year to update in the categories.
        Returns:
            None
        """
        category_r = category_r.lower().replace("category:", "").strip()
        if not ar_year:
            category_lab_2 = category_lab.replace("بعقد ", "عقد ")
            ar_year = self.match_ar_time(category_lab_2)

        if not en_year:
            en_year = self.match_en_time(category_r)

        if en_year.isdigit() and not ar_year:
            ar_year = en_year

        if not ar_year or ar_year not in category_lab:
            return False

        if not en_year or en_year not in category_r:
            return False

        cat_key = category_r.replace(en_year, YEAR_PARAM)
        lab_key = category_lab.replace(ar_year, YEAR_PARAM)

        logger.debug("<<yellow>> lab_from_year_add:")
        logger.debug(f"\t<<yellow>> {cat_key=} , {lab_key=}")

        self.category_templates[cat_key.lower()] = lab_key
        return True



"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats.new_resolvers.reslove_all import new_resolvers_all

test_data_not_for_2018_bot = {
    "weightlifters": "رباعون",
    "judoka": "لاعبو جودو",
    "pan-africanists": "وحدويون أفارقة",
    "swimmers": "سباحون",
    "football players": "لاعبو كرة قدم",
    "athletes": "لاعبو قوى",
    "competitors": "منافسون",
    "cross-country skiers": "متزحلقون ريفيون",
}

te4_2018_Jobs_data = {
    "european sports coaches": "مدربو رياضة أوروبيون",
    "albanian sports coaches": "مدربو رياضة ألبان",
    # "macedonian expatriate female footballers": "لاعبات كرة قدم مقدونيات مغتربات",
    "afghan competitors": "منافسون أفغان",
    "african tennis players": "لاعبو كرة مضرب أفارقة",
    "albanian male tennis players": "لاعبو كرة مضرب ذكور ألبان",
    "albanian physicians": "أطباء ألبان",
    "albanian writers": "كتاب ألبان",
    "algerian expatriate sports-people": "رياضيون جزائريون مغتربون",
    "american agronomists": "مهندسون زراعيون أمريكيون",
    "american artists": "فنانون أمريكيون",
    "american basketball players": "لاعبو كرة سلة أمريكيون",
    "american bluegrass musicians": "موسيقيو بلوغراس أمريكيون",
    "american cricketers": "لاعبو كريكت أمريكيون",
    "american expatriates": "أمريكيون مغتربون",
    "american explorers": "مستكشفون أمريكيون",
    "american female athletes": "لاعبات قوى أمريكيات",
    "american folk musicians": "موسيقيو فولك أمريكيون",
    "american gospel singers": "مغنو غوسبل أمريكيون",
    "american novelists": "روائيون أمريكيون",
    "american playback singers": "مغنو أفلام أمريكيون",
    "american women folk singers": "مغنيات فولك أمريكيات",
    "american women geographers": "جغرافيات أمريكيات",
    "american women guitarists": "عازفات قيثارة أمريكيات",
    "angolan radio journalists": "صحفيو راديو أنغوليون",
    "argentine expatriate sports-people": "رياضيون أرجنتينيون مغتربون",
    "argentine expatriates": "أرجنتينيون مغتربون",
    "argentine industrial designers": "مصممون صناعيون أرجنتينيون",
    "armenian cross-country skiers": "متزحلقون ريفيون أرمن",
    "armenian expatriate sports-people": "رياضيون أرمن مغتربون",
    "asian politicians": "سياسيون آسيويون",
    "australian comedy writers": "كتاب كوميديا أستراليون",
    "australian expatriate sports-people": "رياضيون أستراليون مغتربون",
    "australian heavy metal singers": "مغنو هيفي ميتال أستراليون",
    "australian male sculptors": "نحاتون ذكور أستراليون",
    "australian male sprinters": "عداؤون سريعون ذكور أستراليون",
    "australian oncologists": "أطباء أورام أستراليون",
    "australian science writers": "كتاب علم أستراليون",
    "austrian classical violinists": "عازفو كمان كلاسيكيون نمساويون",
    "austrian film directors": "مخرجو أفلام نمساويون",
    "austrian pianists": "عازفو بيانو نمساويون",
    "austrian religious workers": "عمال دينيون نمساويون",
    "azerbaijani judges": "قضاة أذربيجانيون",
    "azerbaijani logicians": "منطقيون أذربيجانيون",
    "bangladeshi women artists": "فنانات بنغلاديشيات",
    "belarusian computer programmers": "مبرمجون بيلاروسيون",
    "belarusian female tennis players": "لاعبات كرة مضرب بيلاروسيات",
    "belarusian science fiction writers": "كتاب خيال علمي بيلاروسيون",
    "belizean expatriates": "بليزيون مغتربون",
    "beninese male boxers": "ملاكمون ذكور بنينيون",
    "bissau-guinean expatriate sports-people": "رياضيون غينيون بيساويون مغتربون",
    "bolivian expatriate sports-people": "رياضيون بوليفيون مغتربون",
    "bolivian lawyers": "محامون بوليفيون",
    "bolivian pianists": "عازفو بيانو بوليفيون",
    "bosnia and herzegovina artists": "فنانون بوسنيون",
    "bosnia and herzegovina female judoka": "لاعبات جودو بوسنيات",
    "brazilian artists": "فنانون برازيليون",
    "brazilian eugenicists": "علماء برازيليون متخصصون في تحسين النسل",
    "brazilian graphic novelists": "روائيو رويات مصورة برازيليون",
    "brazilian heavy metal guitarists": "عازفو قيثارة هيفي ميتال برازيليون",
    "british cardinals": "كرادلة بريطانيون",
    "british conceptual artists": "فنانون تصويريون بريطانيون",
    "british disability rights activists": "بريطانيون ناشطون في حقوق الإعاقة",
    "british emigrants": "بريطانيون مهاجرون",
    "british engineers": "مهندسون بريطانيون",
    "british expatriate field hockey players": "لاعبو هوكي ميدان بريطانيون مغتربون",
    "british expatriate sports-people": "رياضيون بريطانيون مغتربون",
    "british military personnel": "أفراد عسكريون بريطانيون",
    "british music industry executives": "مدراء صناعة الموسيقى بريطانيون",
    "bulgarian actors": "ممثلون بلغاريون",
    "bulgarian male opera singers": "مغنو أوبرا ذكور بلغاريون",
    "bulgarian priests": "كهنة بلغاريون",
    "bulgarian producers": "منتجون بلغاريون",
    "burkinabe expatriates": "بوركينابيون مغتربون",
    "burkinabe theatre people": "مسرحيون بوركينابيون",
    "cambodian radio journalists": "صحفيو راديو كمبوديون",
    "cameroonian communists": "شيوعيون كاميرونيون",
    "canadian expatriate ice hockey players": "لاعبو هوكي جليد كنديون مغتربون",
    "canadian expatriate sports-people": "رياضيون كنديون مغتربون",
    "canadian expatriates": "كنديون مغتربون",
    "canadian folk rock musicians": "موسيقيو فولك روك كنديون",
    "canadian ice dancers": "راقصو جليد كنديون",
    "canadian male biathletes": "لاعبو بياثلون ذكور كنديون",
    "canadian male kickboxers": "مقاتلو كيك بوكسنغ ذكور كنديون",
    "canadian musicians": "موسيقيون كنديون",
    "canadian sports businesspeople": "شخصيات أعمال رياضيون كنديون",
    "canadian sportsmen": "رياضيون رجال كنديون",
    "cape verdean essayists": "كتاب مقالات أخضريون",
    "cape verdean football managers": "مدربو كرة قدم أخضريون",
    "chechen rebels": "متمردون شيشانيون",
    "chilean expatriates": "تشيليون مغتربون",
    "chilean freestyle skiers": "ممارسو تزلج حر تشيليون",
    "chilean short story writers": "كتاب قصة قصيرة تشيليون",
    "chinese automotive engineers": "مهندسو سيارات صينيون",
    "chinese emigrants": "صينيون مهاجرون",
    "chinese expatriate sports-people": "رياضيون صينيون مغتربون",
    "chinese gamblers": "مقامرون صينيون",
    "chinese stage actors": "ممثلو مسرح صينيون",
    "chinese urban planners": "مخططون حضريون صينيون",
    "colombian composers": "ملحنون كولومبيون",
    "colombian expatriate sports-people": "رياضيون كولومبيون مغتربون",
    "colombian folk singers": "مغنو فولك كولومبيون",
    "croatian baroque composers": "ملحنو باروك كروات",
    "croatian emigrants": "كروات مهاجرون",
    "croatian endocrinologists": "أطباء غدد صماء كروات",
    "croatian expatriates": "كروات مغتربون",
    "cuban poets": "شعراء كوبيون",
    "cypriot emigrants": "قبرصيون مهاجرون",
    "cypriot rugby union players": "لاعبو اتحاد رجبي قبرصيون",
    "czech painters": "رسامون تشيكيون",
    "czechoslovak ice hockey coaches": "مدربو هوكي جليد تشيكوسلوفاكيون",
    "danish ceramists": "خزفيون دنماركيون",
    "danish musicians": "موسيقيون دنماركيون",
    "democratic-republic-of-congo expatriate sports-people": "رياضيون كونغويون ديمقراطيون مغتربون",
    "dutch surveyors": "مساحون هولنديون",
    "egyptian female sport shooters": "لاعبات رماية مصريات",
    "egyptian lawyers": "محامون مصريون",
    "egyptian male sport shooters": "لاعبو رماية ذكور مصريون",
    "egyptian sport shooters": "لاعبو رماية مصريون",
    "english artists": "فنانون إنجليز",
    "english book and manuscript collectors": "جامعو كتب ومقتنيات إنجليز",
    "english cartographers": "علماء رسم خرائط إنجليز",
    "english expatriates": "إنجليز مغتربون",
    "english singer-songwriters": "مغنون وكتاب أغاني إنجليز",
    "english women": "إنجليزيات",
    "equatoguinean female footballers": "لاعبات كرة قدم غينيات استوائيات",
    "equatoguinean women": "غينيات استوائيات",
    "estonian astrologers": "منجمون إستونيون",
    "estonian motorcycle racers": "متسابقو دراجات نارية إستونيون",
    "estonian racing drivers": "سائقو سيارات سباق إستونيون",
    "estonian screenwriters": "كتاب سيناريو إستونيون",
    "ethiopian basketball players": "لاعبو كرة سلة إثيوبيون",
    "ethiopian people imprisoned abroad": "إثيوبيون مسجونون في الخارج",
    "fijian football managers": "مدربو كرة قدم فيجيون",
    "fijian long jumpers": "لاعبو قفز طويل فيجيون",
    "filipino newspaper people": "شخصيات صحف فلبينيون",
    "finnish expatriate sports-people": "رياضيون فنلنديون مغتربون",
    "finnish expatriates": "فنلنديون مغتربون",
    "finnish women archaeologists": "عالمات آثار فنلنديات",
    "finnish women's ice hockey defencemen": "مدافعات هوكي جليد فنلنديات",
    "french male painters": "رسامون ذكور فرنسيون",
    "french male singer-songwriters": "مغنون وكتاب أغاني ذكور فرنسيون",
    "french scholars-of-islam": "فرنسيون باحثون عن الإسلام",
    "french sportsmen": "رياضيون رجال فرنسيون",
    "french women performance artists": "فنانات أدائيات فرنسيات",
    "german advertising executives": "مدراء إعلانات ألمان",
    "german emigrants": "ألمان مهاجرون",
    "german expatriate sports-people": "رياضيون ألمان مغتربون",
    "german expatriates": "ألمان مغتربون",
    "german footballers": "لاعبو كرة قدم ألمان",
    "german male pianists": "عازفو بيانو ذكور ألمان",
    "german women civil servants": "موظفات خدمة مدنية ألمانيات",
    "ghanaian expatriates": "غانيون مغتربون",
    "ghanaian women editors": "محررات غانيات",
    "greek expatriates": "يونانيون مغتربون",
    "greek female prostitutes": "داعرات يونانيات",
    "greek male dancers": "راقصون ذكور يونانيون",
    "greek prisoners": "مسجونون يونانيون",
    "greek slaves": "عبيد يونانيون",
    "greek sports-people": "رياضيون يونانيون",
    "greek women writers": "كاتبات يونانيات",
    "haitian expatriate sports-people": "رياضيون هايتيون مغتربون",
    "haitian officials": "مسؤولون هايتيون",
    "honduran economists": "اقتصاديون هندوراسيون",
    "honduran women poets": "شاعرات هندوراسيات",
    "hong kong female rowers": "مجدفات هونغ كونغيات",
    "hungarian flautists": "عازفو فولت مجريون",
    "hungarian male opera singers": "مغنو أوبرا ذكور مجريون",
    "icelandic actresses": "ممثلات آيسلنديات",
    "icelandic emigrants": "آيسلنديون مهاجرون",
    "indian cricketers": "لاعبو كريكت هنود",
    "indian explorers": "مستكشفون هنود",
    "indian muslim missionaries": "مبشرون مسلمون هنود",
    "indian politicians": "سياسيون هنود",
    "indian scholars": "دارسون هنود",
    "indian translators": "مترجمون هنود",
    "indian women flautists": "عازفات فولت هنديات",
    "indian women lawyers": "محاميات هنديات",
    "indian women writers": "كاتبات هنديات",
    "iranian criminals": "مجرمون إيرانيون",
    "iranian photographers": "مصورون إيرانيون",
    "iranian poets": "شعراء إيرانيون",
    "irish female sailors (sport)": "بحارات رياضيات أيرلنديات",
    "irish male musicians": "موسيقيون ذكور أيرلنديون",
    "irish women aviators": "طيارات أيرلنديات",
    "irish women fashion designers": "مصممات أزياء أيرلنديات",
    "israeli agronomists": "مهندسون زراعيون إسرائيليون",
    "israeli artists": "فنانون إسرائيليون",
    "israeli criminals": "مجرمون إسرائيليون",
    "israeli expatriate sports-people": "رياضيون إسرائيليون مغتربون",
    "israeli male stage actors": "ممثلو مسرح ذكور إسرائيليون",
    "italian emigrants": "إيطاليون مهاجرون",
    "italian male mixed martial artists": "مقاتلو فنون قتالية مختلطة ذكور إيطاليون",
    "italian medical historians": "مؤرخون طبيون إيطاليون",
    "italian military personnel": "أفراد عسكريون إيطاليون",
    "italian physicians": "أطباء إيطاليون",
    "italian rowers": "مجدفون إيطاليون",
    "italian women librarians": "أمينات مكتبات إيطاليات",
    "italian writers": "كتاب إيطاليون",
    "ivorian expatriate sports-people": "رياضيون إيفواريون مغتربون",
    "ivorian writers": "كتاب إيفواريون",
    "jamaican expatriate sports-people": "رياضيون جامايكيون مغتربون",
    "jamaican expatriates": "جامايكيون مغتربون",
    "jamaican women poets": "شاعرات جامايكيات",
    "japanese prisoners": "مسجونون يابانيون",
    "japanese social scientists": "مختصون بالعلوم الاجتماعية يابانيون",
    "jordanian equestrians": "فرسان خيول أردنيون",
    "jordanian expatriate sports-people": "رياضيون أردنيون مغتربون",
    "kazakhstani artists": "فنانون كازاخستانيون",
    "kazakhstani expatriates": "كازاخستانيون مغتربون",
    "kazakhstani football referees": "حكام كرة قدم كازاخستانيون",
    "korean scientists": "علماء كوريون",
    "kosovan pianists": "عازفو بيانو كوسوفيون",
    "kosovan victims of crime": "ضحايا جرائم كوسوفيون",
    "kuwaiti female cyclists": "دراجات كويتيات",
    "kuwaiti nationalists": "قوميون كويتيون",
    "kuwaiti women writers": "كاتبات كويتيات",
    "latvian expatriate sports-people": "رياضيون لاتفيون مغتربون",
    "latvian kickboxers": "مقاتلو كيك بوكسنغ لاتفيون",
    "lithuanian children": "أطفال ليتوانيون",
    "lithuanian expatriates": "ليتوانيون مغتربون",
    "luxembourgian cross-country skiers": "متزحلقون ريفيون لوكسمبورغيون",
    "macedonian male taekwondo practitioners": "لاعبو تايكوندو ذكور مقدونيون",
    "malaysian expatriates": "ماليزيون مغتربون",
    "malian artists": "فنانون ماليون",
    "maltese artisans": "حرفيون مالطيون",
    "maltese christian missionaries": "مبشرون مسيحيون مالطيون",
    "mexican actresses": "ممثلات مكسيكيات",
    "mexican comedians": "كوميديون مكسيكيون",
    "mexican crime fiction writers": "كتاب خيال الجريمة مكسيكيون",
    "mexican expatriates": "مكسيكيون مغتربون",
    "moldovan expatriates": "مولدوفيون مغتربون",
    "mongolian cross-country skiers": "متزحلقون ريفيون منغوليون",
    "mongolian female skiers": "متزحلقات منغوليات",
    "moravian bishops": "أساقفة مورافيون",
    "moroccan expatriate sports-people": "رياضيون مغاربة مغتربون",
    "moroccan male mixed martial artists": "مقاتلو فنون قتالية مختلطة ذكور مغاربة",
    "namibian long jumpers": "لاعبو قفز طويل ناميبيون",
    "nepalese clergy": "رجال دين نيباليون",
    "nepalese cross-country skiers": "متزحلقون ريفيون نيباليون",
    "nigerian expatriate sports-people": "رياضيون نيجيريون مغتربون",
    "nigerian musicians": "موسيقيون نيجيريون",
    "north korean women athletes": "لاعبات قوى كوريات شماليات",
    "norwegian artists": "فنانون نرويجيون",
    "norwegian botanists": "علماء نباتات نرويجيون",
    "norwegian expatriates": "نرويجيون مغتربون",
    "omani politicians": "سياسيون عمانيون",
    "pakistani expatriate actors": "ممثلون باكستانيون مغتربون",
    "pakistani pop singers": "مغنو بوب باكستانيون",
    "panamanian anti-communists": "بنميون مناهضون للشيوعية",
    "panamanian expatriates": "بنميون مغتربون",
    "paraguayan male actors": "ممثلون ذكور بارغوايانيون",
    "paraguayan singers": "مغنون بارغوايانيون",
    "paraguayan surgeons": "جراحون بارغوايانيون",
    "peruvian female freestyle swimmers": "سباحات تزلج حر بيرويات",
    "peruvian women": "بيرويات",
    "polish contraltos": "كونترالتويون بولنديون",
    "polish emigrants": "بولنديون مهاجرون",
    "polish expatriate sports-people": "رياضيون بولنديون مغتربون",
    "polish fascists": "فاشيون بولنديون",
    "polish magazine founders": "مؤسسو مجلات بولنديون",
    "polish rock singers": "مغنو روك بولنديون",
    "polish screenwriters": "كتاب سيناريو بولنديون",
    "polish sports executives and administrators": "مسيرون رياضيون بولنديون",
    "polish sportswomen": "رياضيات بولنديات",
    "portuguese composers": "ملحنون برتغاليون",
    "portuguese expatriate sports-people": "رياضيون برتغاليون مغتربون",
    "portuguese monarchs": "ملكيون برتغاليون",
    "portuguese poets": "شعراء برتغاليون",
    "prussian military personnel": "أفراد عسكريون بروسيون",
    "puerto rican equestrians": "فرسان خيول بورتوريكيون",
    "puerto rican rhythmic gymnasts": "لاعبو جمباز إيقاعي بورتوريكيون",
    "puerto rican sportsmen": "رياضيون رجال بورتوريكيون",
    "puerto rican women": "بورتوريكيات",
    "republic-of-congo expatriate sports-people": "رياضيون كونغويون مغتربون",
    "roman governors": "حكام رومان",
    "romanian geodesists": "جيوديسيون رومان",
    "romanian women radio presenters": "مذيعات راديو رومانيات",
    "russian artists": "فنانون روس",
    "russian botanists": "علماء نباتات روس",
    "russian expatriate sports-people": "رياضيون روس مغتربون",
    "russian expatriates": "روس مغتربون",
    "russian male voice actors": "ممثلو أداء صوتي ذكور روس",
    "salvadoran sportswomen": "رياضيات سلفادوريات",
    "saudiarabian astronauts": "رواد فضاء سعوديون",
    "scottish expatriates": "إسكتلنديون مغتربون",
    "scottish fashion designers": "مصممو أزياء إسكتلنديون",
    "scottish male golfers": "لاعبو غولف ذكور إسكتلنديون",
    "scottish women civil servants": "موظفات خدمة مدنية إسكتلنديات",
    "senegalese expatriate sports-people": "رياضيون سنغاليون مغتربون",
    "serbian expatriates": "صرب مغتربون",
    "serbian journalists": "صحفيون صرب",
    "serbian muay thai practitioners": "ممارسو موياي تاي صرب",
    "serbian political philosophers": "فلاسفة سياسيون صرب",
    "sierra leonean expatriate sports-people": "رياضيون سيراليونيون مغتربون",
    "sierra leonean lawyers": "محامون سيراليونيون",
    "singaporean artists": "فنانون سنغافوريون",
    "slovak expatriate sports-people": "رياضيون سلوفاكيون مغتربون",
    "slovak jazz singers": "مغنو جاز سلوفاكيون",
    "slovak musicians": "موسيقيون سلوفاكيون",
    "slovak sports-people": "رياضيون سلوفاكيون",
    "slovenian explorers": "مستكشفون سلوفينيون",
    "slovenian football referees": "حكام كرة قدم سلوفينيون",
    "south american pan-africanists": "وحدويون أفارقة أمريكيون جنوبيون",
    "south korean expatriates": "كوريون جنوبيون مغتربون",
    "south korean male biathletes": "لاعبو بياثلون ذكور كوريون جنوبيون",
    "south korean songwriters": "كتاب أغان كوريون جنوبيون",
    "south sudanese expatriate sports-people": "رياضيون سودانيون جنوبيون مغتربون",
    "soviet biochemists": "كيميائيون حيويون سوفيت",
    "soviet filmmakers": "صانعو أفلام سوفيت",
    "soviet male figure skaters": "متزلجون فنيون ذكور سوفيت",
    "soviet theatre people": "مسرحيون سوفيت",
    "spanish composers": "ملحنون إسبان",
    "spanish graphic novelists": "روائيو رويات مصورة إسبان",
    "spanish journalists": "صحفيون إسبان",
    "spanish male biographers": "كتاب سيرة ذكور إسبان",
    "spanish nuns": "راهبات إسبانيات",
    "spanish philosophers": "فلاسفة إسبان",
    "spanish women fashion designers": "مصممات أزياء إسبانيات",
    "sri lankan emigrants": "سريلانكيون مهاجرون",
    "sri lankan male kabaddi players": "لاعبو كابادي ذكور سريلانكيون",
    "sri lankan mechanical engineers": "مهندسو ميكانيك سريلانكيون",
    "sri lankan military personnel": "أفراد عسكريون سريلانكيون",
    "sri lankan television actresses": "ممثلات تلفزيون سريلانكيات",
    "swedish artists": "فنانون سويديون",
    "swedish badminton players": "لاعبو تنس ريشة سويديون",
    "swedish dancers": "راقصون سويديون",
    "swedish expatriates": "سويديون مغتربون",
    "swedish inventors": "مخترعون سويديون",
    "swedish male archers": "نبالون ذكور سويديون",
    "swedish women guitarists": "عازفات قيثارة سويديات",
    "swiss emigrants": "سويسريون مهاجرون",
    "swiss expatriate sports-people": "رياضيون سويسريون مغتربون",
    "swiss lugers": "زاحفون ثلجيون سويسريون",
    "swiss murder victims": "ضحايا قتل سويسريون",
    "swiss radio actors": "ممثلو راديو سويسريون",
    "swiss rowers": "مجدفون سويسريون",
    "syrian female table tennis players": "لاعبات كرة طاولة سوريات",
    "taiwanese catholics": "كاثوليك تايوانيون",
    "taiwanese emigrants": "تايوانيون مهاجرون",
    "taiwanese female cyclists": "دراجات تايوانيات",
    "taiwanese politicians": "سياسيون تايوانيون",
    "tanzanian expatriate sports-people": "رياضيون تنزانيون مغتربون",
    "thai lesbians": "سحاقيات تايلنديات",
    "togolese bishops": "أساقفة توغويون",
    "togolese expatriate sports-people": "رياضيون توغويون مغتربون",
    "togolese female footballers": "لاعبات كرة قدم توغويات",
    "tongan rugby league coaches": "مدربو دوري رجبي تونغانيون",
    "trinidad and tobago rugby union players": "لاعبو اتحاد رجبي ترنيداديون",
    "tunisian male fencers": "مبارزون ذكور تونسيون",
    "turkish women athletes": "لاعبات قوى تركيات",
    "ukrainian artists": "فنانون أوكرانيون",
    "ukrainian expatriate sports-people": "رياضيون أوكرانيون مغتربون",
    "ukrainian female pair skaters": "متزلجات فنيات على الجليد أوكرانيات",
    "uruguayan actors": "ممثلون أوروغويانيون",
    "uruguayan dramatists and playwrights": "كتاب دراما ومسرح أوروغويانيون",
    "uruguayan dramatists": "دراميون أوروغويانيون",
    "uzbekistani environmentalists": "بيئيون أوزبكستانيون",
    "venezuelan emigrants": "فنزويليون مهاجرون",
    "venezuelan expatriate sports-people": "رياضيون فنزويليون مغتربون",
    "venezuelan male poets": "شعراء ذكور فنزويليون",
    "venezuelan surgeons": "جراحون فنزويليون",
    "vietnamese female freestyle swimmers": "سباحات تزلج حر فيتناميات",
    "vietnamese sports-people": "رياضيون فيتناميون",
    "welsh athletes": "لاعبو قوى ويلزيون",
    "welsh classical scholars": "باحثون كلاسيكيون ويلزيون",
    "welsh clergy": "رجال دين ويلزيون",
    "welsh comedians": "كوميديون ويلزيون",
    "welsh expatriate footballers": "لاعبو كرة قدم ويلزيون مغتربون",
    "welsh expatriates": "ويلزيون مغتربون",
    "welsh jazz composers": "ملحنو جاز ويلزيون",
    "welsh musicians": "موسيقيون ويلزيون",
    "welsh satirists": "كتاب هجائيون ويلزيون",
    "welsh sports businesspeople": "شخصيات أعمال رياضيون ويلزيون",
    "yugoslav sprinters": "عداؤون سريعون يوغسلافيون",
    "zambian emigrants": "زامبيون مهاجرون",
    "zambian writers": "كتاب زامبيون",
    "zimbabwean expatriates": "زيمبابويون مغتربون",
    "zimbabwean marxists": "ماركسيون زيمبابويون",
}

data_fast = {
    "afghan diplomats": "دبلوماسيون أفغان",
    "afghan emigrants": "أفغان مهاجرون",
    "afghan expatriates": "أفغان مغتربون",
    "american award winners": "حائزو جوائز أمريكيون",
    "american basketball coaches": "مدربو كرة سلة أمريكيون",
    "american cinema editors": "محررون سينمائون أمريكيون",
    "american nuclear medicine physicians": "أطباء طب نووي أمريكيون",
    "argentine multi-instrumentalists": "عازفون على عدة آلات أرجنتينيون",
    "argentine songwriters": "كتاب أغان أرجنتينيون",
    "australian internet celebrities": "مشاهير إنترنت أستراليون",
    "belgian athletics coaches": "مدربو ألعاب قوى بلجيكيون",
    "british editorial cartoonists": "محررون كارتونيون بريطانيون",
    "british television chefs": "طباخو تلفاز بريطانيون",
    "canadian nuclear medicine physicians": "أطباء طب نووي كنديون",
    "croatian nuclear medicine physicians": "أطباء طب نووي كروات",
    "dutch explorers": "مستكشفون هولنديون",
    "egyptian oncologists": "أطباء أورام مصريون",
    "european women": "أوروبيات",
    "german nuclear medicine physicians": "أطباء طب نووي ألمان",
    "icelandic male athletes": "لاعبو قوى ذكور آيسلنديون",
    "icelandic male runners": "عداؤون ذكور آيسلنديون",
    "icelandic male steeplechase runners": "عداؤو موانع ذكور آيسلنديون",
    "iranian nuclear medicine physicians": "أطباء طب نووي إيرانيون",
    "irish football managers": "مدربو كرة قدم أيرلنديون",
    "italian defectors": "إيطاليون منشقون",
    "ivorian emigrants": "إيفواريون مهاجرون",
    "ivorian expatriates": "إيفواريون مغتربون",
    "moroccan competitors": "منافسون مغاربة",
    "moroccan male middle-distance runners": "عداؤو مسافات متوسطة ذكور مغاربة",
    "norwegian figure skaters": "متزلجون فنيون نرويجيون",
    "norwegian male pair skaters": "متزلجون فنيون على الجليد ذكور نرويجيون",
    "norwegian male single skaters": "متزلجون فرديون ذكور نرويجيون",
    "norwegian pair skaters": "متزلجون فنيون على الجليد نرويجيون",
    "norwegian short track speed skaters": "متزلجون على مسار قصير نرويجيون",
    "pakistani psychiatrists": "أطباء نفسيون باكستانيون",
    "peruvian television actors": "ممثلو تلفزيون بيرويون",
    "polish women": "بولنديات",
    "portuguese healthcare managers": "مدراء رعاية صحية برتغاليون",
    "republic-of ireland football managers": "مدربو كرة قدم أيرلنديون",
    "swedish oncologists": "أطباء أورام سويديون",
    "turkish expatriate sports-people": "رياضيون أتراك مغتربون",
}


@pytest.mark.parametrize("category, expected_key", te4_2018_Jobs_data.items(), ids=te4_2018_Jobs_data.keys())
@pytest.mark.slow
def test_te4_2018_Jobs_data(category: str, expected_key: str) -> None:
    label1 = new_resolvers_all(category)
    assert label1 == expected_key

    # label2 = new_resolvers_all(category)
    # assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_data_fast(category: str, expected_key: str) -> None:
    label1 = new_resolvers_all(category)
    assert label1 == expected_key

    # label2 = new_resolvers_all(category)
    # assert label2 == expected_key


to_test = [
    ("test_data_not_for_2018_bot_m", test_data_not_for_2018_bot, new_resolvers_all),
    ("te4_2018_Jobs_data", te4_2018_Jobs_data, new_resolvers_all),
    ("te4_2018_data_fast", data_fast, new_resolvers_all),
]


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

religions_data = {
    "Children's books about Islam and Muslims": "تصنيف:كتب أطفال عن الإسلام ومسلمون",
    "Conspiracy theories involving Muslims": "تصنيف:نظريات مؤامرة تشمل مسلمون",
    "Discrimination against Muslims": "تصنيف:تمييز ضد مسلمون",
    "Jews and Judaism in Appalachia": "تصنيف:اليهود واليهودية في الأبالاش",
    "Massacres of Muslims": "تصنيف:مذابح في مسلمون",
    "Muslims from Alabama": "تصنيف:مسلمون من ألاباما",
    "Muslims from Arizona": "تصنيف:مسلمون من أريزونا",
    "Muslims from Arkansas": "تصنيف:مسلمون من أركنساس",
    "Muslims from California": "تصنيف:مسلمون من كاليفورنيا",
    "Muslims from Colorado": "تصنيف:مسلمون من كولورادو",
    "Muslims from Connecticut": "تصنيف:مسلمون من كونيتيكت",
    "Muslims from Delaware": "تصنيف:مسلمون من ديلاوير",
    "Muslims from Florida": "تصنيف:مسلمون من فلوريدا",
    "Muslims from Georgia (country)": "تصنيف:مسلمون من جورجيا",
    "Muslims from Georgia (U.S. state)": "تصنيف:مسلمون من ولاية جورجيا",
    "Muslims from Idaho": "تصنيف:مسلمون من أيداهو",
    "Muslims from Illinois": "تصنيف:مسلمون من إلينوي",
    "Muslims from Indiana": "تصنيف:مسلمون من إنديانا",
    "Muslims from Iowa": "تصنيف:مسلمون من آيوا",
    "Muslims from Kansas": "تصنيف:مسلمون من كانساس",
    "Muslims from Kentucky": "تصنيف:مسلمون من كنتاكي",
    "Muslims from Louisiana": "تصنيف:مسلمون من لويزيانا",
    "Muslims from Maine": "تصنيف:مسلمون من مين",
    "Muslims from Maryland": "تصنيف:مسلمون من ماريلند",
    "Muslims from Massachusetts": "تصنيف:مسلمون من ماساتشوستس",
    "Muslims from Michigan": "تصنيف:مسلمون من ميشيغان",
    "Muslims from Minnesota": "تصنيف:مسلمون من منيسوتا",
    "Muslims from Mississippi": "تصنيف:مسلمون من مسيسيبي",
    "Muslims from Missouri": "تصنيف:مسلمون من ميزوري",
    "Muslims from Nebraska": "تصنيف:مسلمون من نبراسكا",
    "Muslims from Nevada": "تصنيف:مسلمون من نيفادا",
    "Muslims from New Hampshire": "تصنيف:مسلمون من نيوهامشير",
    "Muslims from New Jersey": "تصنيف:مسلمون من نيوجيرسي",
    "Muslims from New Mexico": "تصنيف:مسلمون من نيومكسيكو",
    "Muslims from New York (state)": "تصنيف:مسلمون من ولاية نيويورك",
    "Muslims from North Carolina": "تصنيف:مسلمون من كارولاينا الشمالية",
    "Muslims from North Dakota": "تصنيف:مسلمون من داكوتا الشمالية",
    "Muslims from Ohio": "تصنيف:مسلمون من أوهايو",
    "Muslims from Oklahoma": "تصنيف:مسلمون من أوكلاهوما",
    "Muslims from Oregon": "تصنيف:مسلمون من أوريغن",
    "Muslims from Overseas France": "تصنيف:مسلمون من مقاطعات وأقاليم ما وراء البحار الفرنسية",
    "Muslims from Pennsylvania": "تصنيف:مسلمون من بنسلفانيا",
    "Muslims from Rhode Island": "تصنيف:مسلمون من رود آيلاند",
    "Muslims from Réunion": "تصنيف:مسلمون من لا ريونيون",
    "Muslims from Tennessee": "تصنيف:مسلمون من تينيسي",
    "Muslims from Texas": "تصنيف:مسلمون من تكساس",
    "Muslims from Ottoman Empire": "تصنيف:مسلمون من الدولة العثمانية",
    "Muslims from Russian Empire": "تصنيف:مسلمون من الإمبراطورية الروسية",
    "Muslims from Virginia": "تصنيف:مسلمون من فرجينيا",
    "Muslims from Washington (state)": "تصنيف:مسلمون من ولاية واشنطن",
    "Muslims from Wisconsin": "تصنيف:مسلمون من ويسكونسن",
    "Muslims": "تصنيف:مسلمون",
    "Persecution of Muslims": "تصنيف:اضطهاد مسلمون",
    "Violence against Muslims by continent": "تصنيف:عنف ضد مسلمون حسب القارة",
    "Violence against Muslims by country": "تصنيف:عنف ضد مسلمون حسب البلد",
    "Violence against Muslims in Asia": "تصنيف:عنف ضد مسلمون في آسيا",
    "Violence against Muslims in North America": "تصنيف:عنف ضد مسلمون في أمريكا الشمالية",
    "Violence against Muslims": "تصنيف:عنف ضد مسلمون",
}

data2 = {
    "Jewish television": "تصنيف:التلفزة اليهودية",
    "Christian television": "تصنيف:التلفزة المسيحية",
    "Jewish musical groups": "تصنيف:فرق موسيقية يهودية",
    "Christian musical groups": "تصنيف:فرق موسيقية مسيحية",
    "Pakistan Muslim League (N)": "تصنيف:الرابطة الإسلامية الباكستانية (ن)",
    "Pakistan Muslim League (Q)": "تصنيف:الجماعة الإسلامية الباكستانية (ق)",
    "People of Jewish Agency for Israel": "تصنيف:أشخاص من الوكالة اليهودية",
    "Police of Nazi Germany": "تصنيف:شرطة ألمانيا النازية",
    "Presidents of Pakistan Muslim League (N)": "تصنيف:رؤساء الرابطة الإسلامية الباكستانية (ن)",
    "Heads of Jewish Agency for Israel": "تصنيف:قادة الوكالة اليهودية",
    "Jewish Agency for Israel": "تصنيف:الوكالة اليهودية",
    "Anti-Jewish pogroms in Russian Empire": "تصنيف:برنامج إبادة اليهود في الإمبراطورية الروسية",
    "Jews from French Mandate for Syria and Lebanon": "تصنيف:يهود من الانتداب الفرنسي على سوريا ولبنان",
}


@pytest.mark.parametrize("category, expected", religions_data.items(), ids=religions_data.keys())
def test_religions_data(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


to_test = [
    ("test_religions_data_1", religions_data),
    ("test_religions_data_2", data2),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



from ..config import print_settings
from ..helps.log import LoggerWrap

logger = LoggerWrap(__name__, disable_log=print_settings.noprint or print_settings.noprint_formats)


__all__ = [
    "logger",
]



#!/usr/bin/python3
"""
Module for single-placeholder category translation formatting.

This module provides the FormatData class for translating category strings
using a single key-value placeholder pattern. It is the primary class for
simple category translations where one dynamic element (e.g., sport name,
nationality) needs to be replaced with its Arabic equivalent.

Classes:
    FormatData: Handles single-placeholder template-driven category translations.

Example:
    >>> from ArWikiCats.translations_formats.DataModel import FormatData
    >>> formatted_data = {
    ...     "{sport} players": "لاعبو {sport_label}",
    ...     "{sport} coaches": "مدربو {sport_label}",
    ... }
    >>> data_list = {
    ...     "football": "كرة القدم",
    ...     "basketball": "كرة السلة",
    ... }
    >>> bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")
    >>> bot.search("football players")
    'لاعبو كرة القدم'
"""

import functools
from typing import Dict

from ..formats_logger import logger
from .model_data_base import FormatDataBase


class FormatData(FormatDataBase):
    """
    Handles single-placeholder template-driven category translations.

    This class extends FormatDataBase to provide functionality for translating
    category strings where a single dynamic element needs to be replaced. It
    uses regex pattern matching to find keys in input categories and replaces
    them with their Arabic equivalents using template strings.

    Attributes:
        formatted_data (Dict[str, str]): Template patterns mapping English patterns to Arabic templates.
        data_list (Dict[str, str]): Key-to-Arabic-label mappings for replacements.
        key_placeholder (str): Placeholder used in formatted_data keys (e.g., "{sport}").
        value_placeholder (str): Placeholder used in formatted_data values (e.g., "{sport_label}").
        text_after (str): Optional text that appears after the key in patterns.
        text_before (str): Optional text that appears before the key in patterns.
        regex_filter (str): Regex pattern for word boundary detection.

    Example:
        >>> bot = FormatData(
        ...     formatted_data={"{sport} players": "لاعبو {sport_label}"},
        ...     data_list={"football": "كرة القدم"},
        ...     key_placeholder="{sport}",
        ...     value_placeholder="{sport_label}",
        ... )
        >>> bot.search("football players")
        'لاعبو كرة القدم'
    """

    def __init__(
        self,
        formatted_data: Dict[str, str],
        data_list: Dict[str, str],
        key_placeholder: str = "xoxo",
        value_placeholder: str = "xoxo",
        text_after: str = "",
        text_before: str = "",
        regex_filter: str = "",
    ) -> None:
        """Prepare helpers for matching and formatting template-driven labels."""
        super().__init__(
            formatted_data=formatted_data,
            data_list=data_list,
            key_placeholder=key_placeholder,
            text_after=text_after,
            text_before=text_before,
            regex_filter=regex_filter,
        )
        self.value_placeholder = value_placeholder
        self.alternation: str = self.create_alternation()
        self.pattern = self.keys_to_pattern()

    @functools.lru_cache(maxsize=None)
    def apply_pattern_replacement(self, template_label: str, sport_label: str) -> str:
        """Replace value placeholder once template is chosen."""
        final_label = template_label.replace(self.value_placeholder, sport_label)

        if self.value_placeholder not in final_label:
            return final_label.strip()

        return ""

    def replace_value_placeholder(self, label: str, value: str) -> str:
        logger.debug(f"!!!! replace_value_placeholder: {self.value_placeholder=}, {label=}, {value=}")
        # Replace placeholder
        return label.replace(self.value_placeholder, value)


def format_data_sample() -> bool:
    """
    This function demonstrates how to use the FormatData class to format and transform data.
    It creates a mapping of template patterns to their localized versions and applies them.
    """
    # Define a dictionary of formatted patterns with placeholders
    formatted_data = {
        "{sport}": "{sport_label}",
        "{sport} managers": "مدربو {sport_label}",
        "{sport} coaches": "مدربو {sport_label}",
        "{sport} people": "أعلام {sport_label}",
        "{sport} playerss": "لاعبو {sport_label}",
        "{sport} players": "لاعبو {sport_label}",
        "men's {sport} matches": "مباريات {sport_label} رجالية",
        "men's {sport} navigational boxes": "صناديق تصفح {sport_label} رجالية",
        "men's {sport} lists": "قوائم {sport_label} رجالية",
        "amateur {sport} home stadiums": "ملاعب {sport_label} للهواة",
        "amateur {sport} templates": "قوالب {sport_label} للهواة",
        "amateur {sport} rivalries": "دربيات {sport_label} للهواة",
        "amateur {sport} receivers": "مستقبلو {sport_label} للهواة",
        "amateur {sport} wide receivers": "مستقبلون واسعون {sport_label} للهواة",
        "amateur {sport} tackles": "مصطدمو {sport_label} للهواة",
        "amateur {sport} utility players": "لاعبو مراكز متعددة {sport_label} للهواة",
    }

    # Define a dictionary with actual sport name mappings
    data_list = {
        "gridiron football": "كرة قدم أمريكية شمالية",
        "american football": "كرة قدم أمريكية",
        "canadian football": "كرة قدم كندية",
        "wheelchair australian rules football": "كرة قدم أسترالية على كراسي متحركة",
        "volleyball racing": "سباق كرة طائرة",
        "wheelchair volleyball": "كرة طائرة على كراسي متحركة",
        "middle-distance running racing": "سباق ركض مسافات متوسطة",
        "wheelchair gaelic football": "كرة قدم غالية على كراسي متحركة",
        "kick boxing racing": "سباق كيك بوكسينغ",
        "wheelchair cycling road race": "سباق دراجات على الطريق على كراسي متحركة",
        "wheelchair auto racing": "سباق سيارات على كراسي متحركة",
    }

    # Create a FormatData instance with the defined patterns and mappings
    bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")

    # Search for a specific pattern and get its localized version
    label = bot.search("american football players")
    # Verify if the result matches the expected output
    result = label == "لاعبو كرة قدم أمريكية"

    # Return the formatted label
    return result



#
import json
from pathlib import Path
from typing import Callable


def dump_one(data: dict, file_name: str) -> None:
    diff_data_path = Path(__file__).parent / "diff_data"
    diff_data_path.mkdir(exist_ok=True, parents=True)
    file_path = diff_data_path / f"{file_name}.json"

    try:
        with open(file_path, "w", encoding="utf-8") as f:
            json.dump(data, f, ensure_ascii=False, indent=4)
    except Exception as e:
        print(f"Error writing diff data: {e}")


def dump_diff(data: dict, file_name: str, _sort: bool = True) -> None:
    if not data:
        return

    if _sort:
        data_sorted = {x: v for x, v in data.items() if v}
        data_sorted.update({y: z for y, z in data.items() if not z})
    else:
        data_sorted = data

    dump_one(data_sorted, file_name)


def dump_diff_text(expected: dict, diff_result: dict, file_name: str) -> None:
    """
    Dump diff data as text file for easy copy-paste to wiki.

    # dump_diff_text(expected, diff_result, name)
    """
    if not expected or not diff_result:
        return

    save3 = [
        f"# {{{{وب:طنت/سطر|{v}|{diff_result[x]}|سبب النقل=تصحيح ArWikiCats}}}}"
        for x, v in expected.items()
        if v and diff_result.get(x)
    ]

    if not save3:
        return

    diff_data_path = Path(__file__).parent / "diff_data"
    diff_data_path.mkdir(exist_ok=True, parents=True)
    file_path = diff_data_path / f"{file_name}_wiki.json"

    text = "\n".join(save3)
    text = text.replace("تصنيف:", "")
    try:
        with open(file_path, "w", encoding="utf-8") as f:
            f.write(text)
    except Exception as e:
        print(f"Error writing diff data: {e}")


def one_dump_test(dataset: dict, callback: Callable[[str], str], do_strip=False) -> tuple[dict, dict]:
    print(f"len of dataset: {len(dataset)}, callback: {callback.__name__}")
    org = {}
    diff = {}
    data = {x: v for x, v in dataset.items()}  # if v
    for cat, ar in data.items():
        result = callback(cat)
        # ---
        if do_strip:
            result = result.strip() if isinstance(result, str) else result
            ar = ar.strip() if isinstance(ar, str) else ar
        # ---
        if result != ar:
            org[cat] = ar
            diff[cat] = result

    return org, diff


def one_dump_test_no_labels(dataset: dict, callback: Callable[[str], str], do_strip=False) -> tuple[dict, dict]:
    print(f"len of dataset: {len(dataset)}, callback: {callback.__name__}")
    org = {}
    diff = {}
    data = {x: v for x, v in dataset.items()}  # if v
    no_labels = []
    for cat, ar in data.items():
        result = callback(cat)
        # ---
        if do_strip:
            result = result.strip() if isinstance(result, str) else result
            ar = ar.strip() if isinstance(ar, str) else ar
        # ---
        if not result:
            no_labels.append(cat)
        elif result != ar:
            org[cat] = ar
            diff[cat] = result
    return org, diff, no_labels


def dump_same_and_not_same(data: dict, diff_result: dict, name: str, just_dump: bool = False) -> None:
    """
    Dump same data as JSON file for easy copy-paste to wiki.

    dump_same_add(data, diff_result, name)
    """
    if not data or not diff_result:
        return

    same_data = {x: v for x, v in data.items() if x not in diff_result}
    if len(same_data) != len(data) or just_dump:
        dump_diff(same_data, f"{name}_same")

    add_data = {x: v for x, v in data.items() if x in diff_result}
    if len(add_data) != len(data) or just_dump:
        dump_diff(add_data, f"{name}_not_same")



"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import make_cnt_lab

make_cnt_lab_data = {
    "jerusalem": "القدس",
    "georgia": "جورجيا",
    "naples": "نابولي",
    "sicily": "صقلية",
    "sardinia": "سردينيا",
    "lagos": "ولاية لاغوس",
    "hanover": "هانوفر",
    "saxony": "ساكسونيا",
    "morocco": "المغرب",
    "galicia": "منطقة غاليسيا",
}


@pytest.mark.parametrize("category, ar", make_cnt_lab_data.items(), ids=make_cnt_lab_data.keys())
@pytest.mark.fast
def test_make_cnt_lab_data(category: str, ar: str) -> None:
    label = make_cnt_lab(
        separator="-of ",
        country=f"kingdom-of {category}",
        part_2_label=ar,
        part_1_label="مملكة",
        part_1_normalized="kingdom of",
        part_2_normalized=category,
        ar_separator=" ",
    )
    assert label == f"مملكة {ar}"


party_data = {
    "vietnam": ("communist party-of vietnam", "فيتنام", "الحزب الشيوعي في فيتنام"),
    "bosnia and herzegovina": (
        "communist party-of bosnia and herzegovina",
        "البوسنة والهرسك",
        "الحزب الشيوعي في البوسنة والهرسك",
    ),
    "cuba": ("communist party-of cuba", "كوبا", "الحزب الشيوعي في كوبا"),
    "soviet union": ("communist party-of soviet union", "الاتحاد السوفيتي", "الحزب الشيوعي في الاتحاد السوفيتي"),
    "yugoslavia": ("communist party-of yugoslavia", "يوغسلافيا", "الحزب الشيوعي في يوغسلافيا"),
}


@pytest.mark.parametrize("country, part_2_label, expected", party_data.values(), ids=party_data.keys())
@pytest.mark.fast
def test_make_cnt_lab_communist_party(country: str, part_2_label: str, expected: str) -> None:
    label = make_cnt_lab(
        separator="-of ",
        country=country,
        part_2_label=part_2_label,
        part_1_label="الحزب الشيوعي في ",
        part_1_normalized="communist party of",
        part_2_normalized=country.replace("communist party-of ", ""),
        ar_separator=" ",
    )

    assert label == expected


congress_data = {
    "103rd": "الثالث بعد المئة",
    "104th": "الرابع بعد المئة",
    "100th": "المئة",
    "101st": "الأول بعد المئة",
    "102nd": "الثاني بعد المئة",
    "105th": "الخامس بعد المئة",
    "106th": "السادس بعد المئة",
    "107th": "السابع بعد المئة",
    "108th": "الثامن بعد المئة",
    "109th": "التاسع بعد المئة",
    "10th": "العاشر",
    "110th": "العاشر بعد المئة",
    "111th": "الحادي عشر بعد المئة",
    "112th": "الثاني عشر بعد المئة",
    "113th": "الثالث عشر بعد المئة",
    "114th": "الرابع عشر بعد المئة",
    "115th": "الخامس عشر بعد المئة",
    "116th": "السادس عشر بعد المئة",
    "117th": "السابع عشر بعد المئة",
    "118th": "الثامن عشر بعد المئة",
    "119th": "التاسع عشر بعد المئة",
    "11th": "الحادي عشر",
    "12th": "الثاني عشر",
    "13th": "الثالث عشر",
    "14th": "الرابع عشر",
    "15th": "الخامس عشر",
    "16th": "السادس عشر",
}


@pytest.mark.parametrize("category, ar", congress_data.items(), ids=congress_data.keys())
@pytest.mark.fast
def test_congress_data(category: str, ar: str) -> None:
    label = f"الكونغرس الأمريكي {ar}"
    result = make_cnt_lab(
        separator=" of ",
        country=f"acts of {category} united states congress",
        part_2_label=label,
        part_1_label="أفعال",
        part_1_normalized="acts of",
        part_2_normalized=f"{category} united states congress",
        ar_separator=" ",
    )

    assert result == f"أفعال {label}"



#!/usr/bin/python3
"""
TODO: use this code in flowworks

Examples:
    - en: 18th-century nobility from the Holy Roman Empire
    - bad arabic: (نبلاء من الإمبراطورية الرومانية المقدسة القرن 18)
    - good arabic: (نبلاء من الإمبراطورية الرومانية المقدسة في القرن 18)
More examples:
    - https://quarry.wmcloud.org/query/100099

"""
import functools
import re

from ...helps import logger
from ...legacy_bots.matables_bots.table1_bot import get_KAKO
from ...time_resolvers.time_to_arabic import convert_time_to_arabic, match_time_en_first
from ...translations import get_from_new_p17_final, get_from_pf_keys2
from ...translations.mixed.keys2 import medical_keys
from ...translations_formats import FormatDataFrom, MultiDataFormatterYearAndFrom
from ..jobs_resolvers import resolve_jobs_main

FROM_REGEX = re.compile(r"^(.*?) from (.*?)$", re.I)

label_new_keys = {
    # "crown-of aragon": "تاج أرغون",
    # "republic-of venice": "جمهورية البندقية",
    # "republic of geneva": "جمهورية جنيف",
}

jobs_part_labels = {
    "lgbtq people": "أعلام إل جي بي تي كيو",
    "princes": "أمراء",
    "deaths": "وفيات",
    "people": "أشخاص",
    "women": "نساء",
    "womens": "نساء",
    "women's": "نساء",
    "female": "نساء",
}

formatted_data = {
    # "{year1} deaths from {country1}": "وفيات بسبب {country1} في {year1}",
    "{year1} {country1}": "{country1} في {year1}",
}


@functools.lru_cache(maxsize=10000)
def get_job_label(text: str) -> str:
    text = normalize_text(text)
    result = jobs_part_labels.get(text) or resolve_jobs_main(text) or ""

    return result


@functools.lru_cache(maxsize=10000)
def get_from_label(from_part):
    from_label = (
        medical_keys.get(from_part)
        or label_new_keys.get(from_part)
        or get_KAKO(from_part)
        or get_from_pf_keys2(from_part)
        or get_from_new_p17_final(from_part)
        or ""
    )

    return from_label


def normalize_text(text):
    text = text.lower()
    text = text.replace("sportspeople", "sports-people")
    text = text.replace(" the ", " ")
    # text = text.replace("republic of", "republic-of")
    if text.startswith("the "):
        text = text[4:]
    return text.strip()


@functools.lru_cache(maxsize=10000)
def get_label_new(text: str) -> str:
    """Get the Arabic label for a 'job from country' category."""
    text = normalize_text(text)
    match = FROM_REGEX.match(text)
    logger.debug(f"get_label_new: {text=}")

    if not match:
        logger.debug(f"get_label_new: no match: {text=}")
        return ""

    job_part = match.group(1)
    from_part = match.group(2)
    logger.debug(f"get_label_new: {job_part=}, {from_part=}")

    job_label = get_job_label(job_part)
    logger.debug(f"get_label_new: {job_part=}, {job_label=}")

    from_label = get_from_label(from_part)

    if not from_label and "-" in from_part:
        from_label = get_from_label(from_part.replace("-", " "))

    logger.debug(f"get_label_new: {from_part=}, {from_label=}")
    min_word = "من" if job_label != "وفيات" else "بسبب"
    if job_label and from_label:
        return f"{job_label} {min_word} {from_label}"

    return ""


@functools.lru_cache(maxsize=10000)
def match_key_callback(text: str) -> str:
    """Match the country part from 'job from country'."""
    # replace all formatted_data keys from text
    # text = text.replace("{year1} deaths from", "").replace("{year1}", "")

    keys_to_replace = [
        x.replace("{country1}", "").strip() for x in formatted_data.keys() if x.replace("{country1}", "").strip()
    ]
    # sort by len
    keys_to_replace = sorted(
        keys_to_replace,
        key=lambda k: (-k.count(" "), -len(k)),
    )
    for key in keys_to_replace:
        if key in text:
            return text.replace(key, "").strip()
    return text.strip()


@functools.lru_cache(maxsize=1)
def multi_bot_v4() -> MultiDataFormatterYearAndFrom:
    country_bot = FormatDataFrom(
        formatted_data=formatted_data,
        key_placeholder="{country1}",
        value_placeholder="{country1}",
        search_callback=get_label_new,
        match_key_callback=match_key_callback,
    )
    year_bot = FormatDataFrom(
        formatted_data={},
        key_placeholder="{year1}",
        value_placeholder="{year1}",
        search_callback=convert_time_to_arabic,
        match_key_callback=match_time_en_first,
    )
    return MultiDataFormatterYearAndFrom(
        country_bot=country_bot,
        year_bot=year_bot,
        other_key_first=True,
    )


@functools.lru_cache(maxsize=10000)
def resolve_year_job_from_countries(category: str) -> str:
    """Resolve year and job from countries using multi_bot_v4."""
    logger.debug(f"<<yellow>> start resolve_year_job_from_countries: {category=}")
    if not FROM_REGEX.match(category):
        logger.debug(f"<<yellow>> skip resolve_year_job_from_countries: {category=} not FROM_REGEX.match(category)")
        return ""

    category = normalize_text(category)

    _bot = multi_bot_v4()
    # NOTE: search_all creates labels like:
    #  [Category:Non-fiction writers from Northern Ireland by century]:
    #  "تصنيف:كتاب غير روائيين من أيرلنديون شماليون حسب القرن"
    result = _bot.create_label(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_year_job_from_countries: {category=}, {result=}", result)
    return result


__all__ = [
    "get_from_label",
    "get_label_new",
    "resolve_year_job_from_countries",
    "multi_bot_v4",
]



"""
pytest tests/test_big_data.py -m skip2
"""

import json
from pathlib import Path

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label


@pytest.fixture
def example_data(request: pytest.FixtureRequest):
    file_path = request.param
    with open(file_path, "r", encoding="utf-8") as f:
        return json.load(f), file_path.stem


DATA_DIR = Path(__file__).parent.parent.parent / "examples/big_data"
FILE_PATHS = list(DATA_DIR.glob("*.json"))


@pytest.mark.dumpbig
@pytest.mark.parametrize("example_data", FILE_PATHS, indirect=True, ids=lambda p: p.name)
def test_big_data(example_data: tuple[dict[str, str], str]) -> None:
    data, name = example_data
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_0 = {
    "Category:World War II political leaders": "تصنيف:زعماء الحرب العالمية الثانية",
    "Category:Vanuatu political leader navigational boxes": "تصنيف:صناديق تصفح قادة فانواتو السياسيون",
    "Category:Somaliland political leader navigational boxes": "تصنيف:صناديق تصفح قادة أرض الصومال السياسيون",
    "Category:Republic of the Congo political leader navigational boxes": "تصنيف:صناديق تصفح قادة جمهورية الكونغو السياسيين",
    "Category:Northern Mariana Islands political leader navigational boxes": "تصنيف:صناديق تصفح قادة جزر ماريانا الشمالية السياسيون",
    "Category:Ireland political leader navigational boxes": "تصنيف:قوالب تصفح قادة سياسيين أيرلنديين",
    "Category:European Union political leader navigational boxes": "تصنيف:صناديق تصفح قائد سياسي الاتحاد الأوروبي",
}

data_fast = {
    "Category:Zimbabwe political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون زيمبابويون",
    "Category:Yemen political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون يمنيون",
    "Category:Vietnam political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون فيتناميون",
    "Category:United States political leader templates": "تصنيف:قوالب قادة سياسيون أمريكيون",
    "Category:United States political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أمريكيون",
    "Category:United Kingdom political leader templates": "تصنيف:قوالب قادة سياسيون بريطانيون",
    "Category:United Kingdom political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بريطانيون",
    "Category:United Arab Emirates political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إماراتيون",
    "Category:Ukraine political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أوكرانيون",
    "Category:Uganda political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أوغنديون",
    "Category:Turkey political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أتراك",
    "Category:Tunisia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تونسيون",
}

data_slow = {
    "Category:Thailand political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تايلنديون",
    "Category:Taiwan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تايوانيون",
    "Category:Syria political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سوريون",
    "Category:Sweden political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سويديون",
    "Category:Suriname political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سوريناميون",
    "Category:Sudan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سودانيون",
    "Category:Spain political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إسبان",
    "Category:South Sudan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سودانيون جنوبيون",
    "Category:South Korea political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كوريون جنوبيون",
    "Category:South America political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أمريكيون جنوبيون",
    "Category:Somalia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون صوماليون",
    "Category:Slovakia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سلوفاكيون",
    "Category:Sierra Leone political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سيراليونيون",
    "Category:Senegal political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سنغاليون",
    "Category:Saudi Arabia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون سعوديون",
    "Category:Rwanda political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون روانديون",
    "Category:Romania political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون رومان",
    "Category:Portugal political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون برتغاليون",
    "Category:Philippines political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون فلبينيون",
    "Category:Pakistan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون باكستانيون",
    "Category:Ottoman Empire political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون عثمانيون",
    "Category:Oman political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون عمانيون",
    "Category:Oceania political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أوقيانوسيون",
    "Category:North Macedonia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مقدونيون شماليون",
    "Category:North America political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أمريكيون شماليون",
    "Category:Nigeria political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون نيجيريون",
    "Category:Niger political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون نيجريون",
    "Category:New Zealand political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون نيوزيلنديون",
    "Category:Netherlands political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون هولنديون",
    "Category:Namibia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ناميبيون",
    "Category:Myanmar political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ميانماريون",
    "Category:Mozambique political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون موزمبيقيون",
    "Category:Montenegro political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مونتينيغريون",
    "Category:Moldova political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مولدوفيون",
    "Category:Middle East political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون شرقيون أوسطيون",
    "Category:Mexico political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مكسيكيون",
    "Category:Mauritania political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون موريتانيون",
    "Category:Mali political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ماليون",
    "Category:Madagascar political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مدغشقريون",
    "Category:Luxembourg political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون لوكسمبورغيون",
    "Category:Lithuania political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ليتوانيون",
    "Category:Libya political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ليبيون",
    "Category:Liberia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ليبيريون",
    "Category:Lebanon political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون لبنانيون",
    "Category:Laos political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون لاوسيون",
    "Category:Kosovo political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كوسوفيون",
    "Category:Kazakhstan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كازاخستانيون",
    "Category:Jordan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أردنيون",
    "Category:Japan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون يابانيون",
    "Category:Ivory Coast political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إيفواريون",
    "Category:Italy political leader templates": "تصنيف:قوالب قادة سياسيون إيطاليون",
    "Category:Italy political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إيطاليون",
    "Category:Israel political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إسرائيليون",
    "Category:Iraq political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون عراقيون",
    "Category:Iran political leader templates": "تصنيف:قوالب قادة سياسيون إيرانيون",
    "Category:Iran political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إيرانيون",
    "Category:Indonesia political leader templates": "تصنيف:قوالب قادة سياسيون إندونيسيون",
    "Category:India political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون هنود",
    "Category:Iceland political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون آيسلنديون",
    "Category:Hungary political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مجريون",
    "Category:Guyana political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غيانيون",
    "Category:Guinea political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غينيون",
    "Category:Guinea-Bissau political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غينيون بيساويون",
    "Category:Guatemala political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غواتيماليون",
    "Category:Guam political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غواميون",
    "Category:Greece political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون يونانيون",
    "Category:Germany political leader templates": "تصنيف:قوالب قادة سياسيون ألمان",
    "Category:Germany political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ألمان",
    "Category:Gabon political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون غابونيون",
    "Category:France political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون فرنسيون",
    "Category:Finland political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون فنلنديون",
    "Category:Fiji political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون فيجيون",
    "Category:Europe political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أوروبيون",
    "Category:Estonia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون إستونيون",
    "Category:Egypt political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون مصريون",
    "Category:Democratic Republic of the Congo political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كونغويون ديمقراطيون",
    "Category:Czechoslovakia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تشيكوسلوفاكيون",
    "Category:Czech Republic political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تشيكيون",
    "Category:Croatia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كروات",
    "Category:Colombia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كولومبيون",
    "Category:Chad political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون تشاديون",
    "Category:Central African Republic political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أفارقة أوسطيون",
    "Category:Caribbean political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كاريبيون",
    "Category:Cape Verde political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أخضريون",
    "Category:Cameroon political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كاميرونيون",
    "Category:Cambodia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون كمبوديون",
    "Category:Burundi political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بورونديون",
    "Category:Burkina Faso political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بوركينابيون",
    "Category:Bulgaria political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بلغاريون",
    "Category:Brazil political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون برازيليون",
    "Category:Botswana political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بوتسوانيون",
    "Category:Bosnia and Herzegovina political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بوسنيون",
    "Category:Benin political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بنينيون",
    "Category:Bangladesh political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون بنغلاديشيون",
    "Category:Azerbaijan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أذربيجانيون",
    "Category:Austria political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون نمساويون",
    "Category:Asia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون آسيويون",
    "Category:Armenia political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أرمن",
    "Category:Argentina political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أرجنتينيون",
    "Category:Angola political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أنغوليون",
    "Category:Algeria political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون جزائريون",
    "Category:Albania political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون ألبان",
    "Category:Africa political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أفارقة",
    "Category:Afghanistan political leader navigational boxes": "تصنيف:صناديق تصفح قادة سياسيون أفغان",
}

to_test = [
    ("test_political_leader_1", data_fast),
    ("test_political_leader_slow", data_slow),
]


@pytest.mark.parametrize("category, expected", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_political_leader_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data_slow.items(), ids=data_slow.keys())
@pytest.mark.slow
def test_political_leader_slow(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, just_dump=True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
""" """

import pytest

from ArWikiCats.translations.sports.sub_teams_keys import sub_teams_new


def _get_value(category: str) -> None:
    return sub_teams_new.get(category)


examples = {
    "men's a' netball": "كرة الشبكة للرجال للمحليين",
    "men's a' nordic combined racing": "سباق التزلج النوردي المزدوج للرجال للمحليين",
    "youth orienteering": "سباق موجه للشباب",
    "youth pair skating racing": "سباق التزلج الفني على الجليد للشباب",
    "men's a' triathlon": "السباق الثلاثي للرجال للمحليين",
    "men's a' triple jump racing": "سباق القفز الثلاثي للرجال للمحليين",
    "figure skating racing mass media": "إعلام سباق التزلج الفني",
    "figure skating racing non-playing staff": "طاقم سباق التزلج الفني غير اللاعبين",
}


@pytest.mark.parametrize(
    "category, expected",
    examples.items(),
    ids=[k for k in examples],
)
def test_resolves_basic_templates(category: str, expected: str) -> None:
    """Templates driven by the lightweight map should translate correctly."""

    result = _get_value(category)
    assert result == expected


olympic_examples = {
    "figure skating racing olympic champions": "أبطال سباق تزلج فني أولمبي",
    "figure skating olympic": "تزلج فني أولمبي",
    "figure skating olympics": "تزلج فني أولمبي",
    "jujutsu racing non-playing staff": "طاقم سباق جوجوتسو غير اللاعبين",
    "jujutsu racing olympic champions": "أبطال سباق جوجوتسو أولمبي",
    "olympic eventing racing": "سباق محاكمة خيول أولمبية",
    "olympic eventing": "محاكمة خيول أولمبية",
    "olympic fencing racing": "سباق مبارزة سيف شيش أولمبية",
    "olympic fencing": "مبارزة سيف شيش أولمبية",
    "olympic field hockey racing": "سباق هوكي ميدان أولمبي",
    "olympic field hockey": "هوكي ميدان أولمبي",
    "olympic fifa futsal world cup racing": "سباق كأس العالم لكرة الصالات الأولمبية",
    "olympic fifa futsal world cup": "كأس العالم لكرة الصالات الأولمبية",
    "olympic fifa world cup racing": "سباق كأس العالم لكرة القدم الأولمبية",
}


@pytest.mark.parametrize(
    "category, expected",
    olympic_examples.items(),
    ids=[k for k in olympic_examples],
)
def test_handles_olympic_variants(category: str, expected: str) -> None:
    """Olympic templates should rely on the shared helper translation."""

    result = _get_value(category)
    assert result == expected



import pytest

from ArWikiCats.translations.nats.Nationality import (
    build_en_nat_entries,
)

# -------------------------------------------------------------------
# Tests for build_en_nat_entries
# -------------------------------------------------------------------


@pytest.mark.fast
def test_build_en_nat_entries() -> None:
    """build_en_nat_entries should process the entry for 'trinidad and tobago' and include 'trinidadian'."""

    data = {
        "trinidad and tobago": {
            "en_nat": "trinidadian",
            "male": "ترنيدادي",
            "males": "ترنيداديون",
            "female": "ترنيدادية",
            "females": "ترنيداديات",
            "the_male": "الترنيدادي",
            "the_female": "الترنيدادية",
            "en": "trinidad and tobago",
            "ar": "ترينيداد وتوباغو",
        }
    }

    result = build_en_nat_entries(data)

    assert isinstance(result, dict)
    assert "trinidadian" in result
    entry = result["trinidadian"]
    assert entry["male"] == "ترنيدادي"
    assert entry["en"] == "trinidad and tobago"
    assert entry["ar"] == "ترينيداد وتوباغو"
